# coding: utf-8

"""
    PowerBot - Webservice for algotrading

    # TERMS AND CONDITIONS The PowerBot system provides B2B services for trading at intraday power markets. By using the PowerBot service, each user agrees to the terms and conditions of this licence: 1. The user confirms that they are familiar with the exchanges trading system and all relevant rules, is professionally qualified and in possession of a trading license for the relevant exchange. 2. The user will comply with the exchanges market rules (e.g. [EPEX Spot Market Rules](https://www.epexspot.com/en/downloads#rules-fees-processes) or [Nord Pool Market Rules](https://www.nordpoolgroup.com/trading/Rules-and-regulations/)) and will not endanger the exchange system at any time with heavy load from trading algorithms or by other use. 3. The user is aware of limits imposed by the exchange. 4. The user is solely liable for actions resulting from the use of PowerBot.   # INTRODUCTION PowerBot is a web-based software service enabling algorithmic trading on intraday power exchanges such as EPEX, Nord Pool, HUPX, BSP Southpool, TGE, OPCOM or ETPA. The service is straightforward to integrate in an existing software environment and provides a variety of programming interfaces for development of individual trading algorithms and software tools. Besides enabling fully automated intraday trading, it can be used to create tools for human traders providing relevant information and trading opportunities or can be integrated in existing software tools. For further details see https://www.powerbot-trading.com  ## Knowledge Base In addition to this API guide, please find the documentation at https://docs.powerbot-trading.com - the password will be provided by the PowerBot team. If not, please reach out to us at support@powerbot-trading.com  ## Endpoints The PowerBot service is available at the following REST endpoints:  | Instance      | Base URL for REST Endpoints                                      | |---------------|------------------------------------------------------------------| | EPEX          | https://staging.powerbot-trading.com/playground/epex/v2/api      | | Nord Pool     | https://staging.powerbot-trading.com/playground/nordpool/v2/api  | | HUPX          | https://staging.powerbot-trading.com/playground/hupx/v2/api      | | BSP Southpool | https://staging.powerbot-trading.com/playground/southpool/v2/api | | TGE           | https://staging.powerbot-trading.com/playground/tge/v2/api       | | IBEX          | https://staging.powerbot-trading.com/playground/ibex/v2/api      | | CROPEX        | https://staging.powerbot-trading.com/playground/cropex/v2/api    | | OPCOM         | https://staging.powerbot-trading.com/playground/opcom/v2/api     | | ETPA          | https://staging.powerbot-trading.com/playground/etpa/v2/api      | | BRM           | https://staging.powerbot-trading.com/playground/brm/v2/api       |  Access to endpoints is secured via an API Key, which needs to be passed as an \"api_key\" header in each request.   Notes on API Keys:  * API keys are specific to Test, Staging or Production.  * API keys are generated by the system administrator and need to be requested.  ## How to generate API clients (libraries) This OpenAPI specification can be used to generate API clients (programming libraries) for a wide range of programming languages using tools like [OpenAPI Generator](https://openapi-generator.tech/). A detailed guide can be found in the [knowledge base](https://docs.powerbot-trading.com/articles/getting-started/generating-clients/).  ## PowerBot Python client For Python, a ready-made client is also available on PyPI and can be downloaded locally via:  ```shell   pip install powerbot-client ```  ## Errors The API uses standard HTTP status codes to indicate the success or failure of the API call. The body of the response will be in JSON format as follows:  ``` {   \"message\": \"... an error message ...\" } ```  ## Paging The API uses offset and limit parameters for paged operations. An X-Total-Count header is added to responses to indicate the total number of items in a paged response.  ## API Rate Limiting The API limits the number of concurrent calls to 50 - when that limit is reached, the client will receive 503 http status codes (service unavailable) with the following text:  ``` {   \"message\": \"API rate limit exceeded\" } ``` Clients should ensure that they stay within the limit for concurrent API calls.    ## Additional code samples Additional information and code samples demonstrating the use of the API can be found at in our [knowledge base](https://docs.powerbot-trading.com/docs/programmatic-access/)  # noqa: E501

    The version of the OpenAPI document: 2.21.0-rc1
    Contact: office@powerbot-trading.com
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from powerbot_asyncio_client.configuration import Configuration


class RelatedContract(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'contract_id': 'str',
        'product': 'str',
        'delivery_area': 'str',
        'active_since': 'datetime',
        'revision': 'int',
        'sequence_number': 'int',
        'delivery_start': 'datetime',
        'delivery_end': 'datetime',
        'best_own_bid_price': 'float',
        'best_own_bid_quantity': 'float',
        'best_own_ask_price': 'float',
        'best_own_ask_quantity': 'float',
        'best_third_party_bid_price': 'float',
        'best_third_party_bid_quantity': 'float',
        'best_third_party_ask_price': 'float',
        'best_third_party_ask_quantity': 'float',
        'last_price': 'float',
        'last_quantity': 'float'
    }

    attribute_map = {
        'contract_id': 'contract_id',
        'product': 'product',
        'delivery_area': 'delivery_area',
        'active_since': 'active_since',
        'revision': 'revision',
        'sequence_number': 'sequence_number',
        'delivery_start': 'delivery_start',
        'delivery_end': 'delivery_end',
        'best_own_bid_price': 'best_own_bid_price',
        'best_own_bid_quantity': 'best_own_bid_quantity',
        'best_own_ask_price': 'best_own_ask_price',
        'best_own_ask_quantity': 'best_own_ask_quantity',
        'best_third_party_bid_price': 'best_third_party_bid_price',
        'best_third_party_bid_quantity': 'best_third_party_bid_quantity',
        'best_third_party_ask_price': 'best_third_party_ask_price',
        'best_third_party_ask_quantity': 'best_third_party_ask_quantity',
        'last_price': 'last_price',
        'last_quantity': 'last_quantity'
    }

    def __init__(self, contract_id=None, product=None, delivery_area=None, active_since=None, revision=None, sequence_number=None, delivery_start=None, delivery_end=None, best_own_bid_price=None, best_own_bid_quantity=None, best_own_ask_price=None, best_own_ask_quantity=None, best_third_party_bid_price=None, best_third_party_bid_quantity=None, best_third_party_ask_price=None, best_third_party_ask_quantity=None, last_price=None, last_quantity=None, local_vars_configuration=None):  # noqa: E501
        """RelatedContract - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._contract_id = None
        self._product = None
        self._delivery_area = None
        self._active_since = None
        self._revision = None
        self._sequence_number = None
        self._delivery_start = None
        self._delivery_end = None
        self._best_own_bid_price = None
        self._best_own_bid_quantity = None
        self._best_own_ask_price = None
        self._best_own_ask_quantity = None
        self._best_third_party_bid_price = None
        self._best_third_party_bid_quantity = None
        self._best_third_party_ask_price = None
        self._best_third_party_ask_quantity = None
        self._last_price = None
        self._last_quantity = None
        self.discriminator = None

        if contract_id is not None:
            self.contract_id = contract_id
        if product is not None:
            self.product = product
        if delivery_area is not None:
            self.delivery_area = delivery_area
        if active_since is not None:
            self.active_since = active_since
        if revision is not None:
            self.revision = revision
        if sequence_number is not None:
            self.sequence_number = sequence_number
        if delivery_start is not None:
            self.delivery_start = delivery_start
        if delivery_end is not None:
            self.delivery_end = delivery_end
        if best_own_bid_price is not None:
            self.best_own_bid_price = best_own_bid_price
        if best_own_bid_quantity is not None:
            self.best_own_bid_quantity = best_own_bid_quantity
        if best_own_ask_price is not None:
            self.best_own_ask_price = best_own_ask_price
        if best_own_ask_quantity is not None:
            self.best_own_ask_quantity = best_own_ask_quantity
        if best_third_party_bid_price is not None:
            self.best_third_party_bid_price = best_third_party_bid_price
        if best_third_party_bid_quantity is not None:
            self.best_third_party_bid_quantity = best_third_party_bid_quantity
        if best_third_party_ask_price is not None:
            self.best_third_party_ask_price = best_third_party_ask_price
        if best_third_party_ask_quantity is not None:
            self.best_third_party_ask_quantity = best_third_party_ask_quantity
        if last_price is not None:
            self.last_price = last_price
        if last_quantity is not None:
            self.last_quantity = last_quantity

    @property
    def contract_id(self):
        """Gets the contract_id of this RelatedContract.  # noqa: E501


        :return: The contract_id of this RelatedContract.  # noqa: E501
        :rtype: str
        """
        return self._contract_id

    @contract_id.setter
    def contract_id(self, contract_id):
        """Sets the contract_id of this RelatedContract.


        :param contract_id: The contract_id of this RelatedContract.  # noqa: E501
        :type contract_id: str
        """

        self._contract_id = contract_id

    @property
    def product(self):
        """Gets the product of this RelatedContract.  # noqa: E501

        The contract's product.  # noqa: E501

        :return: The product of this RelatedContract.  # noqa: E501
        :rtype: str
        """
        return self._product

    @product.setter
    def product(self, product):
        """Sets the product of this RelatedContract.

        The contract's product.  # noqa: E501

        :param product: The product of this RelatedContract.  # noqa: E501
        :type product: str
        """

        self._product = product

    @property
    def delivery_area(self):
        """Gets the delivery_area of this RelatedContract.  # noqa: E501

        The EIC of the delivery area of the order book's product.  # noqa: E501

        :return: The delivery_area of this RelatedContract.  # noqa: E501
        :rtype: str
        """
        return self._delivery_area

    @delivery_area.setter
    def delivery_area(self, delivery_area):
        """Sets the delivery_area of this RelatedContract.

        The EIC of the delivery area of the order book's product.  # noqa: E501

        :param delivery_area: The delivery_area of this RelatedContract.  # noqa: E501
        :type delivery_area: str
        """

        self._delivery_area = delivery_area

    @property
    def active_since(self):
        """Gets the active_since of this RelatedContract.  # noqa: E501

        The timestamp (UTC) since when the contract has been observed as active for trading in the corresponding delivery area. Is reset to current time after a system or market outage or after the market was hibernated. Can be used to determine potential low liquidity situations after activation of new contracts or market outages.  # noqa: E501

        :return: The active_since of this RelatedContract.  # noqa: E501
        :rtype: datetime
        """
        return self._active_since

    @active_since.setter
    def active_since(self, active_since):
        """Sets the active_since of this RelatedContract.

        The timestamp (UTC) since when the contract has been observed as active for trading in the corresponding delivery area. Is reset to current time after a system or market outage or after the market was hibernated. Can be used to determine potential low liquidity situations after activation of new contracts or market outages.  # noqa: E501

        :param active_since: The active_since of this RelatedContract.  # noqa: E501
        :type active_since: datetime
        """

        self._active_since = active_since

    @property
    def revision(self):
        """Gets the revision of this RelatedContract.  # noqa: E501

        Revision number of the order book.  # noqa: E501

        :return: The revision of this RelatedContract.  # noqa: E501
        :rtype: int
        """
        return self._revision

    @revision.setter
    def revision(self, revision):
        """Sets the revision of this RelatedContract.

        Revision number of the order book.  # noqa: E501

        :param revision: The revision of this RelatedContract.  # noqa: E501
        :type revision: int
        """

        self._revision = revision

    @property
    def sequence_number(self):
        """Gets the sequence_number of this RelatedContract.  # noqa: E501

        DEPRECATED: use revision instead  # noqa: E501

        :return: The sequence_number of this RelatedContract.  # noqa: E501
        :rtype: int
        """
        return self._sequence_number

    @sequence_number.setter
    def sequence_number(self, sequence_number):
        """Sets the sequence_number of this RelatedContract.

        DEPRECATED: use revision instead  # noqa: E501

        :param sequence_number: The sequence_number of this RelatedContract.  # noqa: E501
        :type sequence_number: int
        """

        self._sequence_number = sequence_number

    @property
    def delivery_start(self):
        """Gets the delivery_start of this RelatedContract.  # noqa: E501

        Delivery start of the contract.  # noqa: E501

        :return: The delivery_start of this RelatedContract.  # noqa: E501
        :rtype: datetime
        """
        return self._delivery_start

    @delivery_start.setter
    def delivery_start(self, delivery_start):
        """Sets the delivery_start of this RelatedContract.

        Delivery start of the contract.  # noqa: E501

        :param delivery_start: The delivery_start of this RelatedContract.  # noqa: E501
        :type delivery_start: datetime
        """

        self._delivery_start = delivery_start

    @property
    def delivery_end(self):
        """Gets the delivery_end of this RelatedContract.  # noqa: E501

        Delivery end of the contract.  # noqa: E501

        :return: The delivery_end of this RelatedContract.  # noqa: E501
        :rtype: datetime
        """
        return self._delivery_end

    @delivery_end.setter
    def delivery_end(self, delivery_end):
        """Sets the delivery_end of this RelatedContract.

        Delivery end of the contract.  # noqa: E501

        :param delivery_end: The delivery_end of this RelatedContract.  # noqa: E501
        :type delivery_end: datetime
        """

        self._delivery_end = delivery_end

    @property
    def best_own_bid_price(self):
        """Gets the best_own_bid_price of this RelatedContract.  # noqa: E501

        Best bid price placed by your exchange member.  # noqa: E501

        :return: The best_own_bid_price of this RelatedContract.  # noqa: E501
        :rtype: float
        """
        return self._best_own_bid_price

    @best_own_bid_price.setter
    def best_own_bid_price(self, best_own_bid_price):
        """Sets the best_own_bid_price of this RelatedContract.

        Best bid price placed by your exchange member.  # noqa: E501

        :param best_own_bid_price: The best_own_bid_price of this RelatedContract.  # noqa: E501
        :type best_own_bid_price: float
        """

        self._best_own_bid_price = best_own_bid_price

    @property
    def best_own_bid_quantity(self):
        """Gets the best_own_bid_quantity of this RelatedContract.  # noqa: E501

        Quantity of the best bid placed by your exchange member.  # noqa: E501

        :return: The best_own_bid_quantity of this RelatedContract.  # noqa: E501
        :rtype: float
        """
        return self._best_own_bid_quantity

    @best_own_bid_quantity.setter
    def best_own_bid_quantity(self, best_own_bid_quantity):
        """Sets the best_own_bid_quantity of this RelatedContract.

        Quantity of the best bid placed by your exchange member.  # noqa: E501

        :param best_own_bid_quantity: The best_own_bid_quantity of this RelatedContract.  # noqa: E501
        :type best_own_bid_quantity: float
        """

        self._best_own_bid_quantity = best_own_bid_quantity

    @property
    def best_own_ask_price(self):
        """Gets the best_own_ask_price of this RelatedContract.  # noqa: E501

        Best ask price placed by your exchange member.  # noqa: E501

        :return: The best_own_ask_price of this RelatedContract.  # noqa: E501
        :rtype: float
        """
        return self._best_own_ask_price

    @best_own_ask_price.setter
    def best_own_ask_price(self, best_own_ask_price):
        """Sets the best_own_ask_price of this RelatedContract.

        Best ask price placed by your exchange member.  # noqa: E501

        :param best_own_ask_price: The best_own_ask_price of this RelatedContract.  # noqa: E501
        :type best_own_ask_price: float
        """

        self._best_own_ask_price = best_own_ask_price

    @property
    def best_own_ask_quantity(self):
        """Gets the best_own_ask_quantity of this RelatedContract.  # noqa: E501

        Quantity of the best ask placed your exchange member.  # noqa: E501

        :return: The best_own_ask_quantity of this RelatedContract.  # noqa: E501
        :rtype: float
        """
        return self._best_own_ask_quantity

    @best_own_ask_quantity.setter
    def best_own_ask_quantity(self, best_own_ask_quantity):
        """Sets the best_own_ask_quantity of this RelatedContract.

        Quantity of the best ask placed your exchange member.  # noqa: E501

        :param best_own_ask_quantity: The best_own_ask_quantity of this RelatedContract.  # noqa: E501
        :type best_own_ask_quantity: float
        """

        self._best_own_ask_quantity = best_own_ask_quantity

    @property
    def best_third_party_bid_price(self):
        """Gets the best_third_party_bid_price of this RelatedContract.  # noqa: E501

        Best bid price placed by an exchange member other than yours.  # noqa: E501

        :return: The best_third_party_bid_price of this RelatedContract.  # noqa: E501
        :rtype: float
        """
        return self._best_third_party_bid_price

    @best_third_party_bid_price.setter
    def best_third_party_bid_price(self, best_third_party_bid_price):
        """Sets the best_third_party_bid_price of this RelatedContract.

        Best bid price placed by an exchange member other than yours.  # noqa: E501

        :param best_third_party_bid_price: The best_third_party_bid_price of this RelatedContract.  # noqa: E501
        :type best_third_party_bid_price: float
        """

        self._best_third_party_bid_price = best_third_party_bid_price

    @property
    def best_third_party_bid_quantity(self):
        """Gets the best_third_party_bid_quantity of this RelatedContract.  # noqa: E501

        Quantity of the best bid placed by an exchange member other than yours.  # noqa: E501

        :return: The best_third_party_bid_quantity of this RelatedContract.  # noqa: E501
        :rtype: float
        """
        return self._best_third_party_bid_quantity

    @best_third_party_bid_quantity.setter
    def best_third_party_bid_quantity(self, best_third_party_bid_quantity):
        """Sets the best_third_party_bid_quantity of this RelatedContract.

        Quantity of the best bid placed by an exchange member other than yours.  # noqa: E501

        :param best_third_party_bid_quantity: The best_third_party_bid_quantity of this RelatedContract.  # noqa: E501
        :type best_third_party_bid_quantity: float
        """

        self._best_third_party_bid_quantity = best_third_party_bid_quantity

    @property
    def best_third_party_ask_price(self):
        """Gets the best_third_party_ask_price of this RelatedContract.  # noqa: E501

        Best ask price placed by an exchange member other than yours.  # noqa: E501

        :return: The best_third_party_ask_price of this RelatedContract.  # noqa: E501
        :rtype: float
        """
        return self._best_third_party_ask_price

    @best_third_party_ask_price.setter
    def best_third_party_ask_price(self, best_third_party_ask_price):
        """Sets the best_third_party_ask_price of this RelatedContract.

        Best ask price placed by an exchange member other than yours.  # noqa: E501

        :param best_third_party_ask_price: The best_third_party_ask_price of this RelatedContract.  # noqa: E501
        :type best_third_party_ask_price: float
        """

        self._best_third_party_ask_price = best_third_party_ask_price

    @property
    def best_third_party_ask_quantity(self):
        """Gets the best_third_party_ask_quantity of this RelatedContract.  # noqa: E501

        Quantity of the best ask placed by an exchange member other than yours.  # noqa: E501

        :return: The best_third_party_ask_quantity of this RelatedContract.  # noqa: E501
        :rtype: float
        """
        return self._best_third_party_ask_quantity

    @best_third_party_ask_quantity.setter
    def best_third_party_ask_quantity(self, best_third_party_ask_quantity):
        """Sets the best_third_party_ask_quantity of this RelatedContract.

        Quantity of the best ask placed by an exchange member other than yours.  # noqa: E501

        :param best_third_party_ask_quantity: The best_third_party_ask_quantity of this RelatedContract.  # noqa: E501
        :type best_third_party_ask_quantity: float
        """

        self._best_third_party_ask_quantity = best_third_party_ask_quantity

    @property
    def last_price(self):
        """Gets the last_price of this RelatedContract.  # noqa: E501

        The price of the last trade  All trades in the market area of the contract's delivery area, where at least one side of the trade happened on the current exchange, are included. Trades for the XBID contract of the same delivery period as a local contract and vice versa will also be included. Self trades registered at the exchange and internal trades registered by PowerBot are excluded.  # noqa: E501

        :return: The last_price of this RelatedContract.  # noqa: E501
        :rtype: float
        """
        return self._last_price

    @last_price.setter
    def last_price(self, last_price):
        """Sets the last_price of this RelatedContract.

        The price of the last trade  All trades in the market area of the contract's delivery area, where at least one side of the trade happened on the current exchange, are included. Trades for the XBID contract of the same delivery period as a local contract and vice versa will also be included. Self trades registered at the exchange and internal trades registered by PowerBot are excluded.  # noqa: E501

        :param last_price: The last_price of this RelatedContract.  # noqa: E501
        :type last_price: float
        """

        self._last_price = last_price

    @property
    def last_quantity(self):
        """Gets the last_quantity of this RelatedContract.  # noqa: E501

        The quantity of the last trade  All trades in the market area of the contract's delivery area, where at least one side of the trade happened on the current exchange, are included. Trades for the XBID contract of the same delivery period as a local contract and vice versa will also be included. Self trades registered at the exchange and internal trades registered by PowerBot are excluded.  # noqa: E501

        :return: The last_quantity of this RelatedContract.  # noqa: E501
        :rtype: float
        """
        return self._last_quantity

    @last_quantity.setter
    def last_quantity(self, last_quantity):
        """Sets the last_quantity of this RelatedContract.

        The quantity of the last trade  All trades in the market area of the contract's delivery area, where at least one side of the trade happened on the current exchange, are included. Trades for the XBID contract of the same delivery period as a local contract and vice versa will also be included. Self trades registered at the exchange and internal trades registered by PowerBot are excluded.  # noqa: E501

        :param last_quantity: The last_quantity of this RelatedContract.  # noqa: E501
        :type last_quantity: float
        """

        self._last_quantity = last_quantity

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RelatedContract):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RelatedContract):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    PowerBot - Webservice for algotrading

    # TERMS AND CONDITIONS The PowerBot system provides B2B services for trading at intraday power markets. By using the PowerBot service, each user agrees to the terms and conditions of this licence: 1. The user confirms that they are familiar with the exchanges trading system and all relevant rules, is professionally qualified and in possession of a trading license for the relevant exchange. 2. The user will comply with the exchanges market rules (e.g. [EPEX Spot Market Rules](https://www.epexspot.com/en/downloads#rules-fees-processes) or [Nord Pool Market Rules](https://www.nordpoolgroup.com/trading/Rules-and-regulations/)) and will not endanger the exchange system at any time with heavy load from trading algorithms or by other use. 3. The user is aware of limits imposed by the exchange. 4. The user is solely liable for actions resulting from the use of PowerBot.   # INTRODUCTION PowerBot is a web-based software service enabling algorithmic trading on intraday power exchanges such as EPEX, Nord Pool, HUPX, BSP Southpool, TGE, OPCOM or ETPA. The service is straightforward to integrate in an existing software environment and provides a variety of programming interfaces for development of individual trading algorithms and software tools. Besides enabling fully automated intraday trading, it can be used to create tools for human traders providing relevant information and trading opportunities or can be integrated in existing software tools. For further details see https://www.powerbot-trading.com  ## Knowledge Base In addition to this API guide, please find the documentation at https://docs.powerbot-trading.com - the password will be provided by the PowerBot team. If not, please reach out to us at support@powerbot-trading.com  ## Endpoints The PowerBot service is available at the following REST endpoints:  | Instance      | Base URL for REST Endpoints                                      | |---------------|------------------------------------------------------------------| | EPEX          | https://staging.powerbot-trading.com/playground/epex/v2/api      | | Nord Pool     | https://staging.powerbot-trading.com/playground/nordpool/v2/api  | | HUPX          | https://staging.powerbot-trading.com/playground/hupx/v2/api      | | BSP Southpool | https://staging.powerbot-trading.com/playground/southpool/v2/api | | TGE           | https://staging.powerbot-trading.com/playground/tge/v2/api       | | IBEX          | https://staging.powerbot-trading.com/playground/ibex/v2/api      | | CROPEX        | https://staging.powerbot-trading.com/playground/cropex/v2/api    | | OPCOM         | https://staging.powerbot-trading.com/playground/opcom/v2/api     | | ETPA          | https://staging.powerbot-trading.com/playground/etpa/v2/api      | | BRM           | https://staging.powerbot-trading.com/playground/brm/v2/api       |  Access to endpoints is secured via an API Key, which needs to be passed as an \"api_key\" header in each request.   Notes on API Keys:  * API keys are specific to Test, Staging or Production.  * API keys are generated by the system administrator and need to be requested.  ## How to generate API clients (libraries) This OpenAPI specification can be used to generate API clients (programming libraries) for a wide range of programming languages using tools like [OpenAPI Generator](https://openapi-generator.tech/). A detailed guide can be found in the [knowledge base](https://docs.powerbot-trading.com/articles/getting-started/generating-clients/).  ## PowerBot Python client For Python, a ready-made client is also available on PyPI and can be downloaded locally via:  ```shell   pip install powerbot-client ```  ## Errors The API uses standard HTTP status codes to indicate the success or failure of the API call. The body of the response will be in JSON format as follows:  ``` {   \"message\": \"... an error message ...\" } ```  ## Paging The API uses offset and limit parameters for paged operations. An X-Total-Count header is added to responses to indicate the total number of items in a paged response.  ## API Rate Limiting The API limits the number of concurrent calls to 50 - when that limit is reached, the client will receive 503 http status codes (service unavailable) with the following text:  ``` {   \"message\": \"API rate limit exceeded\" } ``` Clients should ensure that they stay within the limit for concurrent API calls.    ## Additional code samples Additional information and code samples demonstrating the use of the API can be found at in our [knowledge base](https://docs.powerbot-trading.com/docs/programmatic-access/)  # noqa: E501

    The version of the OpenAPI document: 2.21.0-rc1
    Contact: office@powerbot-trading.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from powerbot_asyncio_client.api_client import ApiClient
from powerbot_asyncio_client.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class HistoricDataApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_bulk_exports(self, delivery_area, date, exchange, format, **kwargs):  # noqa: E501
        """Get historic data in bulk  # noqa: E501

        Allows to retrieve historic data in bulk. Note: This query can take a while.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_bulk_exports(delivery_area, date, exchange, format, async_req=True)
        >>> result = thread.get()

        :param delivery_area: The delivery area the data is retrieved from. (required)
        :type delivery_area: str
        :param date: Indicates for what date the data is retrieved. (required)
        :type date: date
        :param exchange: The exchange the data is retrieved from. (required)
        :type exchange: Exchange
        :param format: The format of the exported file. (required)
        :type format: BulkExportsFormat
        :param contracts: Indication if contract specific data should be included in the export.
        :type contracts: bool
        :param trades: Indication if trade specific data should be included in the export.
        :type trades: bool
        :param orders: Indication if order specific data should be included in the export.
        :type orders: bool
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: BulkExportsResponse
        """
        kwargs['_return_http_data_only'] = True
        return self.get_bulk_exports_with_http_info(delivery_area, date, exchange, format, **kwargs)  # noqa: E501

    def get_bulk_exports_with_http_info(self, delivery_area, date, exchange, format, **kwargs):  # noqa: E501
        """Get historic data in bulk  # noqa: E501

        Allows to retrieve historic data in bulk. Note: This query can take a while.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_bulk_exports_with_http_info(delivery_area, date, exchange, format, async_req=True)
        >>> result = thread.get()

        :param delivery_area: The delivery area the data is retrieved from. (required)
        :type delivery_area: str
        :param date: Indicates for what date the data is retrieved. (required)
        :type date: date
        :param exchange: The exchange the data is retrieved from. (required)
        :type exchange: Exchange
        :param format: The format of the exported file. (required)
        :type format: BulkExportsFormat
        :param contracts: Indication if contract specific data should be included in the export.
        :type contracts: bool
        :param trades: Indication if trade specific data should be included in the export.
        :type trades: bool
        :param orders: Indication if order specific data should be included in the export.
        :type orders: bool
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(BulkExportsResponse, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'delivery_area',
            'date',
            'exchange',
            'format',
            'contracts',
            'trades',
            'orders'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_bulk_exports" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'delivery_area' is set
        if self.api_client.client_side_validation and local_var_params.get('delivery_area') is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `delivery_area` when calling `get_bulk_exports`")  # noqa: E501
        # verify the required parameter 'date' is set
        if self.api_client.client_side_validation and local_var_params.get('date') is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `date` when calling `get_bulk_exports`")  # noqa: E501
        # verify the required parameter 'exchange' is set
        if self.api_client.client_side_validation and local_var_params.get('exchange') is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `exchange` when calling `get_bulk_exports`")  # noqa: E501
        # verify the required parameter 'format' is set
        if self.api_client.client_side_validation and local_var_params.get('format') is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `format` when calling `get_bulk_exports`")  # noqa: E501

        if self.api_client.client_side_validation and ('delivery_area' in local_var_params and  # noqa: E501
                                                        len(local_var_params['delivery_area']) > 16):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `delivery_area` when calling `get_bulk_exports`, length must be less than or equal to `16`")  # noqa: E501
        if self.api_client.client_side_validation and ('delivery_area' in local_var_params and  # noqa: E501
                                                        len(local_var_params['delivery_area']) < 16):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `delivery_area` when calling `get_bulk_exports`, length must be greater than or equal to `16`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'delivery_area' in local_var_params:
            path_params['delivery_area'] = local_var_params['delivery_area']  # noqa: E501
        if 'date' in local_var_params:
            path_params['date'] = local_var_params['date']  # noqa: E501

        query_params = []
        if local_var_params.get('exchange') is not None:  # noqa: E501
            query_params.append(('exchange', local_var_params['exchange']))  # noqa: E501
        if local_var_params.get('format') is not None:  # noqa: E501
            query_params.append(('format', local_var_params['format']))  # noqa: E501
        if local_var_params.get('contracts') is not None:  # noqa: E501
            query_params.append(('contracts', local_var_params['contracts']))  # noqa: E501
        if local_var_params.get('trades') is not None:  # noqa: E501
            query_params.append(('trades', local_var_params['trades']))  # noqa: E501
        if local_var_params.get('orders') is not None:  # noqa: E501
            query_params.append(('orders', local_var_params['orders']))  # noqa: E501

        header_params = dict(local_var_params.get('_headers', {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key_security']  # noqa: E501

        response_types_map = {
            200: "BulkExportsResponse",
        }

        return self.api_client.call_api(
            '/historic/bulkexports/{delivery_area}/{date}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def get_historic_orders(self, delivery_area, **kwargs):  # noqa: E501
        """Get order book revisions for historic contracts  # noqa: E501

        Allows to retrieve all order revisions of historic contracts.  Note that this endpoint returns order revisions, and not orders. This means that the same order ID will appear multiple times, once for each update (creation, update or deletion).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_historic_orders(delivery_area, async_req=True)
        >>> result = thread.get()

        :param delivery_area: The delivery area of the target contract. (required)
        :type delivery_area: str
        :param page_size: The number of order book revisions to return in one page.
        :type page_size: int
        :param page_token: Used for request pagination. If a response has the field `next_page_token` set, you can provide that value as the `page_token` parameter to retrieve the next page of results. The first request does not need to have the `page_token` parameter set.
        :type page_token: str
        :param exchange: This value can be used to retrieve data from other exchanges. This is only possible for exchanges you are actively using, or have used in the past.  It defaults to the current exchange if no value is specified.
        :type exchange: Exchange
        :param delivery_start: The delivery start time of the target contract. Must be used together with `delivery_end` and `product`. Alternatively, `contract_id` can be used.
        :type delivery_start: datetime
        :param delivery_end: The delivery end time of the target contract. Must be used together with `delivery_start` and `product`. Alternatively, `contract_id` can be used.
        :type delivery_end: datetime
        :param product: The product of the target contract. Must be used together with `delivery_start` and `delivery_end`. Alternatively, `contract_id` can be used.
        :type product: str
        :param contract_id: The ID of the target contract. Alternatively, `delivery_start`, `delivery_end` and `contract_id` can be used.
        :type contract_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: HistoricOrdersResponse
        """
        kwargs['_return_http_data_only'] = True
        return self.get_historic_orders_with_http_info(delivery_area, **kwargs)  # noqa: E501

    def get_historic_orders_with_http_info(self, delivery_area, **kwargs):  # noqa: E501
        """Get order book revisions for historic contracts  # noqa: E501

        Allows to retrieve all order revisions of historic contracts.  Note that this endpoint returns order revisions, and not orders. This means that the same order ID will appear multiple times, once for each update (creation, update or deletion).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_historic_orders_with_http_info(delivery_area, async_req=True)
        >>> result = thread.get()

        :param delivery_area: The delivery area of the target contract. (required)
        :type delivery_area: str
        :param page_size: The number of order book revisions to return in one page.
        :type page_size: int
        :param page_token: Used for request pagination. If a response has the field `next_page_token` set, you can provide that value as the `page_token` parameter to retrieve the next page of results. The first request does not need to have the `page_token` parameter set.
        :type page_token: str
        :param exchange: This value can be used to retrieve data from other exchanges. This is only possible for exchanges you are actively using, or have used in the past.  It defaults to the current exchange if no value is specified.
        :type exchange: Exchange
        :param delivery_start: The delivery start time of the target contract. Must be used together with `delivery_end` and `product`. Alternatively, `contract_id` can be used.
        :type delivery_start: datetime
        :param delivery_end: The delivery end time of the target contract. Must be used together with `delivery_start` and `product`. Alternatively, `contract_id` can be used.
        :type delivery_end: datetime
        :param product: The product of the target contract. Must be used together with `delivery_start` and `delivery_end`. Alternatively, `contract_id` can be used.
        :type product: str
        :param contract_id: The ID of the target contract. Alternatively, `delivery_start`, `delivery_end` and `contract_id` can be used.
        :type contract_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(HistoricOrdersResponse, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'delivery_area',
            'page_size',
            'page_token',
            'exchange',
            'delivery_start',
            'delivery_end',
            'product',
            'contract_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_historic_orders" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'delivery_area' is set
        if self.api_client.client_side_validation and local_var_params.get('delivery_area') is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `delivery_area` when calling `get_historic_orders`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if local_var_params.get('page_size') is not None:  # noqa: E501
            query_params.append(('page_size', local_var_params['page_size']))  # noqa: E501
        if local_var_params.get('page_token') is not None:  # noqa: E501
            query_params.append(('page_token', local_var_params['page_token']))  # noqa: E501
        if local_var_params.get('exchange') is not None:  # noqa: E501
            query_params.append(('exchange', local_var_params['exchange']))  # noqa: E501
        if local_var_params.get('delivery_area') is not None:  # noqa: E501
            query_params.append(('delivery_area', local_var_params['delivery_area']))  # noqa: E501
        if local_var_params.get('delivery_start') is not None:  # noqa: E501
            query_params.append(('delivery_start', local_var_params['delivery_start']))  # noqa: E501
        if local_var_params.get('delivery_end') is not None:  # noqa: E501
            query_params.append(('delivery_end', local_var_params['delivery_end']))  # noqa: E501
        if local_var_params.get('product') is not None:  # noqa: E501
            query_params.append(('product', local_var_params['product']))  # noqa: E501
        if local_var_params.get('contract_id') is not None:  # noqa: E501
            query_params.append(('contract_id', local_var_params['contract_id']))  # noqa: E501

        header_params = dict(local_var_params.get('_headers', {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key_security']  # noqa: E501

        response_types_map = {
            200: "HistoricOrdersResponse",
        }

        return self.api_client.call_api(
            '/historic/publicorders', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def get_historic_trades(self, **kwargs):  # noqa: E501
        """Get trades for historic contracts  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_historic_trades(async_req=True)
        >>> result = thread.get()

        :param page_size: The number of trades to return in one page. Setting this field to `0` will return all trades if `period_match_exact` is set to `true` or only one contract ID is provided.
        :type page_size: int
        :param page_token: Used for request pagination. If a response has the field `next_page_token` set, you can provide that value as the `page_token` parameter to retrieve the next page of results. The first request does not need to have the `page_token` parameter set.
        :type page_token: str
        :param exchange: This value can be used to retrieve data from other exchanges. This is only possible for exchanges you are actively using, or have used in the past.  It defaults to the current exchange if no value is specified.
        :type exchange: Exchange
        :param period_start: The lower limit (inclusive) of contract delivery periods. Can be set to match contract `delivery_start` exactly with `period_match_exact`
        :type period_start: datetime
        :param period_end: The upper limit (inclusive) of contract delivery periods. Can be set to match contract `delivery_end` exactly with `period_match_exact`
        :type period_end: datetime
        :param period_match_exact: If set to true, only trades for contract with a delivery period that exactly matches `period_start` and `period_end` will be returned. Otherwise, trades for all contracts with a delivery period that fully falls between `period_start` and `period_end` will be considered.
        :type period_match_exact: bool
        :param delivery_period_duration_minutes:
        :type delivery_period_duration_minutes: int
        :param delivery_area_buy:
        :type delivery_area_buy: str
        :param delivery_area_sell:
        :type delivery_area_sell: str
        :param delivery_area_match_exact: If set to true, only trades where the buy **and** sell delivery areas exactly match `delivery_area_buy` and `delivery_area_sell` will be returned. Otherwise, trades where the buy **or** sell delivery areas match `delivery_area_buy` or `delivery_area_sell` will be returned.
        :type delivery_area_match_exact: bool
        :param contract_ids:
        :type contract_ids: list[str]
        :param products:
        :type products: list[str]
        :param execution_from_offset_minutes: Excludes trades that were executed before `delivery_period_start - execution_from_offset_minutes`
        :type execution_from_offset_minutes: int
        :param execution_to_offset_minutes: Excludes trades that were executed after `delivery_period_start - execution_to_offset_minutes`
        :type execution_to_offset_minutes: int
        :param self_trades:
        :type self_trades: SelfTradeSelector
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: HistoricTradesResponse
        """
        kwargs['_return_http_data_only'] = True
        return self.get_historic_trades_with_http_info(**kwargs)  # noqa: E501

    def get_historic_trades_with_http_info(self, **kwargs):  # noqa: E501
        """Get trades for historic contracts  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_historic_trades_with_http_info(async_req=True)
        >>> result = thread.get()

        :param page_size: The number of trades to return in one page. Setting this field to `0` will return all trades if `period_match_exact` is set to `true` or only one contract ID is provided.
        :type page_size: int
        :param page_token: Used for request pagination. If a response has the field `next_page_token` set, you can provide that value as the `page_token` parameter to retrieve the next page of results. The first request does not need to have the `page_token` parameter set.
        :type page_token: str
        :param exchange: This value can be used to retrieve data from other exchanges. This is only possible for exchanges you are actively using, or have used in the past.  It defaults to the current exchange if no value is specified.
        :type exchange: Exchange
        :param period_start: The lower limit (inclusive) of contract delivery periods. Can be set to match contract `delivery_start` exactly with `period_match_exact`
        :type period_start: datetime
        :param period_end: The upper limit (inclusive) of contract delivery periods. Can be set to match contract `delivery_end` exactly with `period_match_exact`
        :type period_end: datetime
        :param period_match_exact: If set to true, only trades for contract with a delivery period that exactly matches `period_start` and `period_end` will be returned. Otherwise, trades for all contracts with a delivery period that fully falls between `period_start` and `period_end` will be considered.
        :type period_match_exact: bool
        :param delivery_period_duration_minutes:
        :type delivery_period_duration_minutes: int
        :param delivery_area_buy:
        :type delivery_area_buy: str
        :param delivery_area_sell:
        :type delivery_area_sell: str
        :param delivery_area_match_exact: If set to true, only trades where the buy **and** sell delivery areas exactly match `delivery_area_buy` and `delivery_area_sell` will be returned. Otherwise, trades where the buy **or** sell delivery areas match `delivery_area_buy` or `delivery_area_sell` will be returned.
        :type delivery_area_match_exact: bool
        :param contract_ids:
        :type contract_ids: list[str]
        :param products:
        :type products: list[str]
        :param execution_from_offset_minutes: Excludes trades that were executed before `delivery_period_start - execution_from_offset_minutes`
        :type execution_from_offset_minutes: int
        :param execution_to_offset_minutes: Excludes trades that were executed after `delivery_period_start - execution_to_offset_minutes`
        :type execution_to_offset_minutes: int
        :param self_trades:
        :type self_trades: SelfTradeSelector
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(HistoricTradesResponse, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'page_size',
            'page_token',
            'exchange',
            'period_start',
            'period_end',
            'period_match_exact',
            'delivery_period_duration_minutes',
            'delivery_area_buy',
            'delivery_area_sell',
            'delivery_area_match_exact',
            'contract_ids',
            'products',
            'execution_from_offset_minutes',
            'execution_to_offset_minutes',
            'self_trades'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_historic_trades" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if local_var_params.get('page_size') is not None:  # noqa: E501
            query_params.append(('page_size', local_var_params['page_size']))  # noqa: E501
        if local_var_params.get('page_token') is not None:  # noqa: E501
            query_params.append(('page_token', local_var_params['page_token']))  # noqa: E501
        if local_var_params.get('exchange') is not None:  # noqa: E501
            query_params.append(('exchange', local_var_params['exchange']))  # noqa: E501
        if local_var_params.get('period_start') is not None:  # noqa: E501
            query_params.append(('period_start', local_var_params['period_start']))  # noqa: E501
        if local_var_params.get('period_end') is not None:  # noqa: E501
            query_params.append(('period_end', local_var_params['period_end']))  # noqa: E501
        if local_var_params.get('period_match_exact') is not None:  # noqa: E501
            query_params.append(('period_match_exact', local_var_params['period_match_exact']))  # noqa: E501
        if local_var_params.get('delivery_period_duration_minutes') is not None:  # noqa: E501
            query_params.append(('delivery_period_duration_minutes', local_var_params['delivery_period_duration_minutes']))  # noqa: E501
        if local_var_params.get('delivery_area_buy') is not None:  # noqa: E501
            query_params.append(('delivery_area_buy', local_var_params['delivery_area_buy']))  # noqa: E501
        if local_var_params.get('delivery_area_sell') is not None:  # noqa: E501
            query_params.append(('delivery_area_sell', local_var_params['delivery_area_sell']))  # noqa: E501
        if local_var_params.get('delivery_area_match_exact') is not None:  # noqa: E501
            query_params.append(('delivery_area_match_exact', local_var_params['delivery_area_match_exact']))  # noqa: E501
        if local_var_params.get('contract_ids') is not None:  # noqa: E501
            query_params.append(('contract_ids', local_var_params['contract_ids']))  # noqa: E501
            collection_formats['contract_ids'] = 'multi'  # noqa: E501
        if local_var_params.get('products') is not None:  # noqa: E501
            query_params.append(('products', local_var_params['products']))  # noqa: E501
            collection_formats['products'] = 'multi'  # noqa: E501
        if local_var_params.get('execution_from_offset_minutes') is not None:  # noqa: E501
            query_params.append(('execution_from_offset_minutes', local_var_params['execution_from_offset_minutes']))  # noqa: E501
        if local_var_params.get('execution_to_offset_minutes') is not None:  # noqa: E501
            query_params.append(('execution_to_offset_minutes', local_var_params['execution_to_offset_minutes']))  # noqa: E501
        if local_var_params.get('self_trades') is not None:  # noqa: E501
            query_params.append(('self_trades', local_var_params['self_trades']))  # noqa: E501

        header_params = dict(local_var_params.get('_headers', {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key_security']  # noqa: E501

        response_types_map = {
            200: "HistoricTradesResponse",
        }

        return self.api_client.call_api(
            '/historic/publictrades', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))



# coding: utf-8

"""
    PowerBot - Webservice for algotrading

    # TERMS AND CONDITIONS The PowerBot system provides B2B services for trading at intraday power markets. By using the PowerBot service, each user agrees to the terms and conditions of this licence: 1. The user confirms that they are familiar with the exchanges trading system and all relevant rules, is professionally qualified and in possession of a trading license for the relevant exchange. 2. The user will comply with the exchanges market rules (e.g. [EPEX Spot Market Rules](https://www.epexspot.com/en/downloads#rules-fees-processes) or [Nord Pool Market Rules](https://www.nordpoolgroup.com/trading/Rules-and-regulations/)) and will not endanger the exchange system at any time with heavy load from trading algorithms or by other use. 3. The user is aware of limits imposed by the exchange. 4. The user is solely liable for actions resulting from the use of PowerBot.   # INTRODUCTION PowerBot is a web-based software service enabling algorithmic trading on intraday power exchanges such as EPEX, Nord Pool, HUPX, BSP Southpool, TGE, OPCOM or ETPA. The service is straightforward to integrate in an existing software environment and provides a variety of programming interfaces for development of individual trading algorithms and software tools. Besides enabling fully automated intraday trading, it can be used to create tools for human traders providing relevant information and trading opportunities or can be integrated in existing software tools. For further details see https://www.powerbot-trading.com  ## Knowledge Base In addition to this API guide, please find the documentation at https://docs.powerbot-trading.com - the password will be provided by the PowerBot team. If not, please reach out to us at support@powerbot-trading.com  ## Endpoints The PowerBot service is available at the following REST endpoints:  | Instance      | Base URL for REST Endpoints                                      | |---------------|------------------------------------------------------------------| | EPEX          | https://staging.powerbot-trading.com/playground/epex/v2/api      | | Nord Pool     | https://staging.powerbot-trading.com/playground/nordpool/v2/api  | | HUPX          | https://staging.powerbot-trading.com/playground/hupx/v2/api      | | BSP Southpool | https://staging.powerbot-trading.com/playground/southpool/v2/api | | TGE           | https://staging.powerbot-trading.com/playground/tge/v2/api       | | IBEX          | https://staging.powerbot-trading.com/playground/ibex/v2/api      | | CROPEX        | https://staging.powerbot-trading.com/playground/cropex/v2/api    | | OPCOM         | https://staging.powerbot-trading.com/playground/opcom/v2/api     | | ETPA          | https://staging.powerbot-trading.com/playground/etpa/v2/api      | | BRM           | https://staging.powerbot-trading.com/playground/brm/v2/api       |  Access to endpoints is secured via an API Key, which needs to be passed as an \"api_key\" header in each request.   Notes on API Keys:  * API keys are specific to Test, Staging or Production.  * API keys are generated by the system administrator and need to be requested.  ## How to generate API clients (libraries) This OpenAPI specification can be used to generate API clients (programming libraries) for a wide range of programming languages using tools like [OpenAPI Generator](https://openapi-generator.tech/). A detailed guide can be found in the [knowledge base](https://docs.powerbot-trading.com/articles/getting-started/generating-clients/).  ## PowerBot Python client For Python, a ready-made client is also available on PyPI and can be downloaded locally via:  ```shell   pip install powerbot-client ```  ## Errors The API uses standard HTTP status codes to indicate the success or failure of the API call. The body of the response will be in JSON format as follows:  ``` {   \"message\": \"... an error message ...\" } ```  ## Paging The API uses offset and limit parameters for paged operations. An X-Total-Count header is added to responses to indicate the total number of items in a paged response.  ## API Rate Limiting The API limits the number of concurrent calls to 50 - when that limit is reached, the client will receive 503 http status codes (service unavailable) with the following text:  ``` {   \"message\": \"API rate limit exceeded\" } ``` Clients should ensure that they stay within the limit for concurrent API calls.    ## Additional code samples Additional information and code samples demonstrating the use of the API can be found at in our [knowledge base](https://docs.powerbot-trading.com/docs/programmatic-access/)  # noqa: E501

    The version of the OpenAPI document: 2.21.0-rc1
    Contact: office@powerbot-trading.com
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from powerbot_asyncio_client.configuration import Configuration


class Auction(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'auction_id': 'str',
        'name': 'str',
        'delivery_start': 'datetime',
        'delivery_end': 'datetime',
        'delivery_areas': 'list[str]',
        'contracts': 'list[AuctionContract]',
        'order_entry_start': 'datetime',
        'order_entry_end': 'datetime',
        'state': 'AuctionState',
        'product_name': 'str',
        'auction_type': 'AuctionType'
    }

    attribute_map = {
        'auction_id': 'auction_id',
        'name': 'name',
        'delivery_start': 'delivery_start',
        'delivery_end': 'delivery_end',
        'delivery_areas': 'delivery_areas',
        'contracts': 'contracts',
        'order_entry_start': 'order_entry_start',
        'order_entry_end': 'order_entry_end',
        'state': 'state',
        'product_name': 'product_name',
        'auction_type': 'auction_type'
    }

    def __init__(self, auction_id=None, name=None, delivery_start=None, delivery_end=None, delivery_areas=None, contracts=None, order_entry_start=None, order_entry_end=None, state=None, product_name=None, auction_type=None, local_vars_configuration=None):  # noqa: E501
        """Auction - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._auction_id = None
        self._name = None
        self._delivery_start = None
        self._delivery_end = None
        self._delivery_areas = None
        self._contracts = None
        self._order_entry_start = None
        self._order_entry_end = None
        self._state = None
        self._product_name = None
        self._auction_type = None
        self.discriminator = None

        self.auction_id = auction_id
        self.name = name
        self.delivery_start = delivery_start
        self.delivery_end = delivery_end
        self.delivery_areas = delivery_areas
        self.contracts = contracts
        if order_entry_start is not None:
            self.order_entry_start = order_entry_start
        self.order_entry_end = order_entry_end
        self.state = state
        if product_name is not None:
            self.product_name = product_name
        if auction_type is not None:
            self.auction_type = auction_type

    @property
    def auction_id(self):
        """Gets the auction_id of this Auction.  # noqa: E501

        The ID of the auction.  # noqa: E501

        :return: The auction_id of this Auction.  # noqa: E501
        :rtype: str
        """
        return self._auction_id

    @auction_id.setter
    def auction_id(self, auction_id):
        """Sets the auction_id of this Auction.

        The ID of the auction.  # noqa: E501

        :param auction_id: The auction_id of this Auction.  # noqa: E501
        :type auction_id: str
        """
        if self.local_vars_configuration.client_side_validation and auction_id is None:  # noqa: E501
            raise ValueError("Invalid value for `auction_id`, must not be `None`")  # noqa: E501

        self._auction_id = auction_id

    @property
    def name(self):
        """Gets the name of this Auction.  # noqa: E501

        The name of the auction.  # noqa: E501

        :return: The name of this Auction.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Auction.

        The name of the auction.  # noqa: E501

        :param name: The name of this Auction.  # noqa: E501
        :type name: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def delivery_start(self):
        """Gets the delivery_start of this Auction.  # noqa: E501

        The first delivery start of the auction.  # noqa: E501

        :return: The delivery_start of this Auction.  # noqa: E501
        :rtype: datetime
        """
        return self._delivery_start

    @delivery_start.setter
    def delivery_start(self, delivery_start):
        """Sets the delivery_start of this Auction.

        The first delivery start of the auction.  # noqa: E501

        :param delivery_start: The delivery_start of this Auction.  # noqa: E501
        :type delivery_start: datetime
        """
        if self.local_vars_configuration.client_side_validation and delivery_start is None:  # noqa: E501
            raise ValueError("Invalid value for `delivery_start`, must not be `None`")  # noqa: E501

        self._delivery_start = delivery_start

    @property
    def delivery_end(self):
        """Gets the delivery_end of this Auction.  # noqa: E501

        The last delivery end of the auction.  # noqa: E501

        :return: The delivery_end of this Auction.  # noqa: E501
        :rtype: datetime
        """
        return self._delivery_end

    @delivery_end.setter
    def delivery_end(self, delivery_end):
        """Sets the delivery_end of this Auction.

        The last delivery end of the auction.  # noqa: E501

        :param delivery_end: The delivery_end of this Auction.  # noqa: E501
        :type delivery_end: datetime
        """
        if self.local_vars_configuration.client_side_validation and delivery_end is None:  # noqa: E501
            raise ValueError("Invalid value for `delivery_end`, must not be `None`")  # noqa: E501

        self._delivery_end = delivery_end

    @property
    def delivery_areas(self):
        """Gets the delivery_areas of this Auction.  # noqa: E501

        The delivery areas where the auction takes place.  # noqa: E501

        :return: The delivery_areas of this Auction.  # noqa: E501
        :rtype: list[str]
        """
        return self._delivery_areas

    @delivery_areas.setter
    def delivery_areas(self, delivery_areas):
        """Sets the delivery_areas of this Auction.

        The delivery areas where the auction takes place.  # noqa: E501

        :param delivery_areas: The delivery_areas of this Auction.  # noqa: E501
        :type delivery_areas: list[str]
        """
        if self.local_vars_configuration.client_side_validation and delivery_areas is None:  # noqa: E501
            raise ValueError("Invalid value for `delivery_areas`, must not be `None`")  # noqa: E501

        self._delivery_areas = delivery_areas

    @property
    def contracts(self):
        """Gets the contracts of this Auction.  # noqa: E501


        :return: The contracts of this Auction.  # noqa: E501
        :rtype: list[AuctionContract]
        """
        return self._contracts

    @contracts.setter
    def contracts(self, contracts):
        """Sets the contracts of this Auction.


        :param contracts: The contracts of this Auction.  # noqa: E501
        :type contracts: list[AuctionContract]
        """
        if self.local_vars_configuration.client_side_validation and contracts is None:  # noqa: E501
            raise ValueError("Invalid value for `contracts`, must not be `None`")  # noqa: E501

        self._contracts = contracts

    @property
    def order_entry_start(self):
        """Gets the order_entry_start of this Auction.  # noqa: E501

        The time after which orders can be started to be placed.  # noqa: E501

        :return: The order_entry_start of this Auction.  # noqa: E501
        :rtype: datetime
        """
        return self._order_entry_start

    @order_entry_start.setter
    def order_entry_start(self, order_entry_start):
        """Sets the order_entry_start of this Auction.

        The time after which orders can be started to be placed.  # noqa: E501

        :param order_entry_start: The order_entry_start of this Auction.  # noqa: E501
        :type order_entry_start: datetime
        """

        self._order_entry_start = order_entry_start

    @property
    def order_entry_end(self):
        """Gets the order_entry_end of this Auction.  # noqa: E501

        The time after which order placement is closed.  # noqa: E501

        :return: The order_entry_end of this Auction.  # noqa: E501
        :rtype: datetime
        """
        return self._order_entry_end

    @order_entry_end.setter
    def order_entry_end(self, order_entry_end):
        """Sets the order_entry_end of this Auction.

        The time after which order placement is closed.  # noqa: E501

        :param order_entry_end: The order_entry_end of this Auction.  # noqa: E501
        :type order_entry_end: datetime
        """
        if self.local_vars_configuration.client_side_validation and order_entry_end is None:  # noqa: E501
            raise ValueError("Invalid value for `order_entry_end`, must not be `None`")  # noqa: E501

        self._order_entry_end = order_entry_end

    @property
    def state(self):
        """Gets the state of this Auction.  # noqa: E501


        :return: The state of this Auction.  # noqa: E501
        :rtype: AuctionState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this Auction.


        :param state: The state of this Auction.  # noqa: E501
        :type state: AuctionState
        """
        if self.local_vars_configuration.client_side_validation and state is None:  # noqa: E501
            raise ValueError("Invalid value for `state`, must not be `None`")  # noqa: E501

        self._state = state

    @property
    def product_name(self):
        """Gets the product_name of this Auction.  # noqa: E501

        The name of the product the auction is applicable to.  # noqa: E501

        :return: The product_name of this Auction.  # noqa: E501
        :rtype: str
        """
        return self._product_name

    @product_name.setter
    def product_name(self, product_name):
        """Sets the product_name of this Auction.

        The name of the product the auction is applicable to.  # noqa: E501

        :param product_name: The product_name of this Auction.  # noqa: E501
        :type product_name: str
        """

        self._product_name = product_name

    @property
    def auction_type(self):
        """Gets the auction_type of this Auction.  # noqa: E501


        :return: The auction_type of this Auction.  # noqa: E501
        :rtype: AuctionType
        """
        return self._auction_type

    @auction_type.setter
    def auction_type(self, auction_type):
        """Sets the auction_type of this Auction.


        :param auction_type: The auction_type of this Auction.  # noqa: E501
        :type auction_type: AuctionType
        """

        self._auction_type = auction_type

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Auction):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Auction):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    PowerBot - Webservice for algotrading

    # TERMS AND CONDITIONS The PowerBot system provides B2B services for trading at intraday power markets. By using the PowerBot service, each user agrees to the terms and conditions of this licence: 1. The user confirms that they are familiar with the exchanges trading system and all relevant rules, is professionally qualified and in possession of a trading license for the relevant exchange. 2. The user will comply with the exchanges market rules (e.g. [EPEX Spot Market Rules](https://www.epexspot.com/en/downloads#rules-fees-processes) or [Nord Pool Market Rules](https://www.nordpoolgroup.com/trading/Rules-and-regulations/)) and will not endanger the exchange system at any time with heavy load from trading algorithms or by other use. 3. The user is aware of limits imposed by the exchange. 4. The user is solely liable for actions resulting from the use of PowerBot.   # INTRODUCTION PowerBot is a web-based software service enabling algorithmic trading on intraday power exchanges such as EPEX, Nord Pool, HUPX, BSP Southpool, TGE, OPCOM or ETPA. The service is straightforward to integrate in an existing software environment and provides a variety of programming interfaces for development of individual trading algorithms and software tools. Besides enabling fully automated intraday trading, it can be used to create tools for human traders providing relevant information and trading opportunities or can be integrated in existing software tools. For further details see https://www.powerbot-trading.com  ## Knowledge Base In addition to this API guide, please find the documentation at https://docs.powerbot-trading.com - the password will be provided by the PowerBot team. If not, please reach out to us at support@powerbot-trading.com  ## Endpoints The PowerBot service is available at the following REST endpoints:  | Instance      | Base URL for REST Endpoints                                      | |---------------|------------------------------------------------------------------| | EPEX          | https://staging.powerbot-trading.com/playground/epex/v2/api      | | Nord Pool     | https://staging.powerbot-trading.com/playground/nordpool/v2/api  | | HUPX          | https://staging.powerbot-trading.com/playground/hupx/v2/api      | | BSP Southpool | https://staging.powerbot-trading.com/playground/southpool/v2/api | | TGE           | https://staging.powerbot-trading.com/playground/tge/v2/api       | | IBEX          | https://staging.powerbot-trading.com/playground/ibex/v2/api      | | CROPEX        | https://staging.powerbot-trading.com/playground/cropex/v2/api    | | OPCOM         | https://staging.powerbot-trading.com/playground/opcom/v2/api     | | ETPA          | https://staging.powerbot-trading.com/playground/etpa/v2/api      | | BRM           | https://staging.powerbot-trading.com/playground/brm/v2/api       |  Access to endpoints is secured via an API Key, which needs to be passed as an \"api_key\" header in each request.   Notes on API Keys:  * API keys are specific to Test, Staging or Production.  * API keys are generated by the system administrator and need to be requested.  ## How to generate API clients (libraries) This OpenAPI specification can be used to generate API clients (programming libraries) for a wide range of programming languages using tools like [OpenAPI Generator](https://openapi-generator.tech/). A detailed guide can be found in the [knowledge base](https://docs.powerbot-trading.com/articles/getting-started/generating-clients/).  ## PowerBot Python client For Python, a ready-made client is also available on PyPI and can be downloaded locally via:  ```shell   pip install powerbot-client ```  ## Errors The API uses standard HTTP status codes to indicate the success or failure of the API call. The body of the response will be in JSON format as follows:  ``` {   \"message\": \"... an error message ...\" } ```  ## Paging The API uses offset and limit parameters for paged operations. An X-Total-Count header is added to responses to indicate the total number of items in a paged response.  ## API Rate Limiting The API limits the number of concurrent calls to 50 - when that limit is reached, the client will receive 503 http status codes (service unavailable) with the following text:  ``` {   \"message\": \"API rate limit exceeded\" } ``` Clients should ensure that they stay within the limit for concurrent API calls.    ## Additional code samples Additional information and code samples demonstrating the use of the API can be found at in our [knowledge base](https://docs.powerbot-trading.com/docs/programmatic-access/)  # noqa: E501

    The version of the OpenAPI document: 2.21.0-rc1
    Contact: office@powerbot-trading.com
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from powerbot_asyncio_client.configuration import Configuration


class PublicTrade(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'trade_id': 'str',
        'buy_delivery_area': 'str',
        'sell_delivery_area': 'str',
        'api_timestamp': 'datetime',
        'exec_time': 'datetime',
        'contract_id': 'str',
        'delivery_start': 'datetime',
        'delivery_end': 'datetime',
        'price': 'float',
        'quantity': 'float',
        'self_trade': 'bool',
        'active': 'bool',
        'state': 'str'
    }

    attribute_map = {
        'trade_id': 'trade_id',
        'buy_delivery_area': 'buy_delivery_area',
        'sell_delivery_area': 'sell_delivery_area',
        'api_timestamp': 'api_timestamp',
        'exec_time': 'exec_time',
        'contract_id': 'contract_id',
        'delivery_start': 'delivery_start',
        'delivery_end': 'delivery_end',
        'price': 'price',
        'quantity': 'quantity',
        'self_trade': 'self_trade',
        'active': 'active',
        'state': 'state'
    }

    def __init__(self, trade_id=None, buy_delivery_area=None, sell_delivery_area=None, api_timestamp=None, exec_time=None, contract_id=None, delivery_start=None, delivery_end=None, price=None, quantity=None, self_trade=None, active=None, state=None, local_vars_configuration=None):  # noqa: E501
        """PublicTrade - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._trade_id = None
        self._buy_delivery_area = None
        self._sell_delivery_area = None
        self._api_timestamp = None
        self._exec_time = None
        self._contract_id = None
        self._delivery_start = None
        self._delivery_end = None
        self._price = None
        self._quantity = None
        self._self_trade = None
        self._active = None
        self._state = None
        self.discriminator = None

        if trade_id is not None:
            self.trade_id = trade_id
        if buy_delivery_area is not None:
            self.buy_delivery_area = buy_delivery_area
        if sell_delivery_area is not None:
            self.sell_delivery_area = sell_delivery_area
        if api_timestamp is not None:
            self.api_timestamp = api_timestamp
        if exec_time is not None:
            self.exec_time = exec_time
        if contract_id is not None:
            self.contract_id = contract_id
        if delivery_start is not None:
            self.delivery_start = delivery_start
        if delivery_end is not None:
            self.delivery_end = delivery_end
        if price is not None:
            self.price = price
        if quantity is not None:
            self.quantity = quantity
        if self_trade is not None:
            self.self_trade = self_trade
        if active is not None:
            self.active = active
        if state is not None:
            self.state = state

    @property
    def trade_id(self):
        """Gets the trade_id of this PublicTrade.  # noqa: E501


        :return: The trade_id of this PublicTrade.  # noqa: E501
        :rtype: str
        """
        return self._trade_id

    @trade_id.setter
    def trade_id(self, trade_id):
        """Sets the trade_id of this PublicTrade.


        :param trade_id: The trade_id of this PublicTrade.  # noqa: E501
        :type trade_id: str
        """

        self._trade_id = trade_id

    @property
    def buy_delivery_area(self):
        """Gets the buy_delivery_area of this PublicTrade.  # noqa: E501

        The delivery area of the buy order  **Note**: this is always set to CZ for OTE, because the exchange does not provide this information  # noqa: E501

        :return: The buy_delivery_area of this PublicTrade.  # noqa: E501
        :rtype: str
        """
        return self._buy_delivery_area

    @buy_delivery_area.setter
    def buy_delivery_area(self, buy_delivery_area):
        """Sets the buy_delivery_area of this PublicTrade.

        The delivery area of the buy order  **Note**: this is always set to CZ for OTE, because the exchange does not provide this information  # noqa: E501

        :param buy_delivery_area: The buy_delivery_area of this PublicTrade.  # noqa: E501
        :type buy_delivery_area: str
        """

        self._buy_delivery_area = buy_delivery_area

    @property
    def sell_delivery_area(self):
        """Gets the sell_delivery_area of this PublicTrade.  # noqa: E501

        The delivery area of the sell order  **Note**: this is always set to CZ for OTE, because the exchange does not provide this information  # noqa: E501

        :return: The sell_delivery_area of this PublicTrade.  # noqa: E501
        :rtype: str
        """
        return self._sell_delivery_area

    @sell_delivery_area.setter
    def sell_delivery_area(self, sell_delivery_area):
        """Sets the sell_delivery_area of this PublicTrade.

        The delivery area of the sell order  **Note**: this is always set to CZ for OTE, because the exchange does not provide this information  # noqa: E501

        :param sell_delivery_area: The sell_delivery_area of this PublicTrade.  # noqa: E501
        :type sell_delivery_area: str
        """

        self._sell_delivery_area = sell_delivery_area

    @property
    def api_timestamp(self):
        """Gets the api_timestamp of this PublicTrade.  # noqa: E501

        The timestamp (UTC) of the information being received from the exchange  # noqa: E501

        :return: The api_timestamp of this PublicTrade.  # noqa: E501
        :rtype: datetime
        """
        return self._api_timestamp

    @api_timestamp.setter
    def api_timestamp(self, api_timestamp):
        """Sets the api_timestamp of this PublicTrade.

        The timestamp (UTC) of the information being received from the exchange  # noqa: E501

        :param api_timestamp: The api_timestamp of this PublicTrade.  # noqa: E501
        :type api_timestamp: datetime
        """

        self._api_timestamp = api_timestamp

    @property
    def exec_time(self):
        """Gets the exec_time of this PublicTrade.  # noqa: E501

        The timestamp (UTC) when the public trade was executed  # noqa: E501

        :return: The exec_time of this PublicTrade.  # noqa: E501
        :rtype: datetime
        """
        return self._exec_time

    @exec_time.setter
    def exec_time(self, exec_time):
        """Sets the exec_time of this PublicTrade.

        The timestamp (UTC) when the public trade was executed  # noqa: E501

        :param exec_time: The exec_time of this PublicTrade.  # noqa: E501
        :type exec_time: datetime
        """

        self._exec_time = exec_time

    @property
    def contract_id(self):
        """Gets the contract_id of this PublicTrade.  # noqa: E501

        The id of the contract on which the public trade was executed  # noqa: E501

        :return: The contract_id of this PublicTrade.  # noqa: E501
        :rtype: str
        """
        return self._contract_id

    @contract_id.setter
    def contract_id(self, contract_id):
        """Sets the contract_id of this PublicTrade.

        The id of the contract on which the public trade was executed  # noqa: E501

        :param contract_id: The contract_id of this PublicTrade.  # noqa: E501
        :type contract_id: str
        """

        self._contract_id = contract_id

    @property
    def delivery_start(self):
        """Gets the delivery_start of this PublicTrade.  # noqa: E501

        Time when the delivery of this trade starts  # noqa: E501

        :return: The delivery_start of this PublicTrade.  # noqa: E501
        :rtype: datetime
        """
        return self._delivery_start

    @delivery_start.setter
    def delivery_start(self, delivery_start):
        """Sets the delivery_start of this PublicTrade.

        Time when the delivery of this trade starts  # noqa: E501

        :param delivery_start: The delivery_start of this PublicTrade.  # noqa: E501
        :type delivery_start: datetime
        """

        self._delivery_start = delivery_start

    @property
    def delivery_end(self):
        """Gets the delivery_end of this PublicTrade.  # noqa: E501

        Time when the delivery of this trade ends  # noqa: E501

        :return: The delivery_end of this PublicTrade.  # noqa: E501
        :rtype: datetime
        """
        return self._delivery_end

    @delivery_end.setter
    def delivery_end(self, delivery_end):
        """Sets the delivery_end of this PublicTrade.

        Time when the delivery of this trade ends  # noqa: E501

        :param delivery_end: The delivery_end of this PublicTrade.  # noqa: E501
        :type delivery_end: datetime
        """

        self._delivery_end = delivery_end

    @property
    def price(self):
        """Gets the price of this PublicTrade.  # noqa: E501

        The price of the trade  # noqa: E501

        :return: The price of this PublicTrade.  # noqa: E501
        :rtype: float
        """
        return self._price

    @price.setter
    def price(self, price):
        """Sets the price of this PublicTrade.

        The price of the trade  # noqa: E501

        :param price: The price of this PublicTrade.  # noqa: E501
        :type price: float
        """

        self._price = price

    @property
    def quantity(self):
        """Gets the quantity of this PublicTrade.  # noqa: E501

        The quantity (usually in MW, but depends on the contract) of the public trade  # noqa: E501

        :return: The quantity of this PublicTrade.  # noqa: E501
        :rtype: float
        """
        return self._quantity

    @quantity.setter
    def quantity(self, quantity):
        """Sets the quantity of this PublicTrade.

        The quantity (usually in MW, but depends on the contract) of the public trade  # noqa: E501

        :param quantity: The quantity of this PublicTrade.  # noqa: E501
        :type quantity: float
        """

        self._quantity = quantity

    @property
    def self_trade(self):
        """Gets the self_trade of this PublicTrade.  # noqa: E501

        Indicates whether the trade was done as a self trade (inside one balancing group or between two different balancing groups within one member).   **Note**: not all exchanges provide this information  # noqa: E501

        :return: The self_trade of this PublicTrade.  # noqa: E501
        :rtype: bool
        """
        return self._self_trade

    @self_trade.setter
    def self_trade(self, self_trade):
        """Sets the self_trade of this PublicTrade.

        Indicates whether the trade was done as a self trade (inside one balancing group or between two different balancing groups within one member).   **Note**: not all exchanges provide this information  # noqa: E501

        :param self_trade: The self_trade of this PublicTrade.  # noqa: E501
        :type self_trade: bool
        """

        self._self_trade = self_trade

    @property
    def active(self):
        """Gets the active of this PublicTrade.  # noqa: E501


        :return: The active of this PublicTrade.  # noqa: E501
        :rtype: bool
        """
        return self._active

    @active.setter
    def active(self, active):
        """Sets the active of this PublicTrade.


        :param active: The active of this PublicTrade.  # noqa: E501
        :type active: bool
        """

        self._active = active

    @property
    def state(self):
        """Gets the state of this PublicTrade.  # noqa: E501


        :return: The state of this PublicTrade.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this PublicTrade.


        :param state: The state of this PublicTrade.  # noqa: E501
        :type state: str
        """
        allowed_values = ["EXECUTED", "RECALL_REQUESTED", "RECALL_REQUESTED_SIDC", "RECALL_REJECTED", "RECALLED", "CANCELLATION_REQUESTED", "CANCELLATION_REJECTED", "CANCELLED"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and state not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `state` ({0}), must be one of {1}"  # noqa: E501
                .format(state, allowed_values)
            )

        self._state = state

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PublicTrade):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PublicTrade):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    PowerBot - Webservice for algotrading

    # TERMS AND CONDITIONS The PowerBot system provides B2B services for trading at intraday power markets. By using the PowerBot service, each user agrees to the terms and conditions of this licence: 1. The user confirms that they are familiar with the exchanges trading system and all relevant rules, is professionally qualified and in possession of a trading license for the relevant exchange. 2. The user will comply with the exchanges market rules (e.g. [EPEX Spot Market Rules](https://www.epexspot.com/en/downloads#rules-fees-processes) or [Nord Pool Market Rules](https://www.nordpoolgroup.com/trading/Rules-and-regulations/)) and will not endanger the exchange system at any time with heavy load from trading algorithms or by other use. 3. The user is aware of limits imposed by the exchange. 4. The user is solely liable for actions resulting from the use of PowerBot.   # INTRODUCTION PowerBot is a web-based software service enabling algorithmic trading on intraday power exchanges such as EPEX, Nord Pool, HUPX, BSP Southpool, TGE, OPCOM or ETPA. The service is straightforward to integrate in an existing software environment and provides a variety of programming interfaces for development of individual trading algorithms and software tools. Besides enabling fully automated intraday trading, it can be used to create tools for human traders providing relevant information and trading opportunities or can be integrated in existing software tools. For further details see https://www.powerbot-trading.com  ## Knowledge Base In addition to this API guide, please find the documentation at https://docs.powerbot-trading.com - the password will be provided by the PowerBot team. If not, please reach out to us at support@powerbot-trading.com  ## Endpoints The PowerBot service is available at the following REST endpoints:  | Instance      | Base URL for REST Endpoints                                      | |---------------|------------------------------------------------------------------| | EPEX          | https://staging.powerbot-trading.com/playground/epex/v2/api      | | Nord Pool     | https://staging.powerbot-trading.com/playground/nordpool/v2/api  | | HUPX          | https://staging.powerbot-trading.com/playground/hupx/v2/api      | | BSP Southpool | https://staging.powerbot-trading.com/playground/southpool/v2/api | | TGE           | https://staging.powerbot-trading.com/playground/tge/v2/api       | | IBEX          | https://staging.powerbot-trading.com/playground/ibex/v2/api      | | CROPEX        | https://staging.powerbot-trading.com/playground/cropex/v2/api    | | OPCOM         | https://staging.powerbot-trading.com/playground/opcom/v2/api     | | ETPA          | https://staging.powerbot-trading.com/playground/etpa/v2/api      | | BRM           | https://staging.powerbot-trading.com/playground/brm/v2/api       |  Access to endpoints is secured via an API Key, which needs to be passed as an \"api_key\" header in each request.   Notes on API Keys:  * API keys are specific to Test, Staging or Production.  * API keys are generated by the system administrator and need to be requested.  ## How to generate API clients (libraries) This OpenAPI specification can be used to generate API clients (programming libraries) for a wide range of programming languages using tools like [OpenAPI Generator](https://openapi-generator.tech/). A detailed guide can be found in the [knowledge base](https://docs.powerbot-trading.com/articles/getting-started/generating-clients/).  ## PowerBot Python client For Python, a ready-made client is also available on PyPI and can be downloaded locally via:  ```shell   pip install powerbot-client ```  ## Errors The API uses standard HTTP status codes to indicate the success or failure of the API call. The body of the response will be in JSON format as follows:  ``` {   \"message\": \"... an error message ...\" } ```  ## Paging The API uses offset and limit parameters for paged operations. An X-Total-Count header is added to responses to indicate the total number of items in a paged response.  ## API Rate Limiting The API limits the number of concurrent calls to 50 - when that limit is reached, the client will receive 503 http status codes (service unavailable) with the following text:  ``` {   \"message\": \"API rate limit exceeded\" } ``` Clients should ensure that they stay within the limit for concurrent API calls.    ## Additional code samples Additional information and code samples demonstrating the use of the API can be found at in our [knowledge base](https://docs.powerbot-trading.com/docs/programmatic-access/)  # noqa: E501

    The version of the OpenAPI document: 2.21.0-rc1
    Contact: office@powerbot-trading.com
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from powerbot_asyncio_client.configuration import Configuration


class Contract(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'product': 'str',
        'contract_id': 'str',
        'sequence_number': 'int',
        'type': 'ContractType',
        'state': 'str',
        'active_since': 'datetime',
        'name': 'str',
        'del_units': 'float',
        'revision_no': 'int',
        'delivery_start': 'datetime',
        'delivery_end': 'datetime',
        'best_bid_price': 'float',
        'best_bid_quantity': 'float',
        'best_ask_price': 'float',
        'best_ask_quantity': 'float',
        'last_price': 'float',
        'last_quantity': 'float',
        'total_quantity': 'float',
        'auction_price': 'float',
        'high': 'float',
        'low': 'float',
        'last_trade_time': 'datetime',
        'signals': 'list[Signal]',
        'vwap': 'float',
        'avwa': 'float',
        'bvwa': 'float',
        'trading_start': 'datetime',
        'trading_end': 'datetime',
        'order_action_quota': 'float',
        'portfolio_information': 'list[PortfolioInformation]'
    }

    attribute_map = {
        'product': 'product',
        'contract_id': 'contract_id',
        'sequence_number': 'sequence_number',
        'type': 'type',
        'state': 'state',
        'active_since': 'active_since',
        'name': 'name',
        'del_units': 'delUnits',
        'revision_no': 'revision_no',
        'delivery_start': 'delivery_start',
        'delivery_end': 'delivery_end',
        'best_bid_price': 'best_bid_price',
        'best_bid_quantity': 'best_bid_quantity',
        'best_ask_price': 'best_ask_price',
        'best_ask_quantity': 'best_ask_quantity',
        'last_price': 'last_price',
        'last_quantity': 'last_quantity',
        'total_quantity': 'total_quantity',
        'auction_price': 'auction_price',
        'high': 'high',
        'low': 'low',
        'last_trade_time': 'last_trade_time',
        'signals': 'signals',
        'vwap': 'vwap',
        'avwa': 'avwa',
        'bvwa': 'bvwa',
        'trading_start': 'trading_start',
        'trading_end': 'trading_end',
        'order_action_quota': 'order_action_quota',
        'portfolio_information': 'portfolio_information'
    }

    def __init__(self, product=None, contract_id=None, sequence_number=None, type=None, state=None, active_since=None, name=None, del_units=None, revision_no=None, delivery_start=None, delivery_end=None, best_bid_price=None, best_bid_quantity=None, best_ask_price=None, best_ask_quantity=None, last_price=None, last_quantity=None, total_quantity=None, auction_price=None, high=None, low=None, last_trade_time=None, signals=None, vwap=None, avwa=None, bvwa=None, trading_start=None, trading_end=None, order_action_quota=None, portfolio_information=None, local_vars_configuration=None):  # noqa: E501
        """Contract - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._product = None
        self._contract_id = None
        self._sequence_number = None
        self._type = None
        self._state = None
        self._active_since = None
        self._name = None
        self._del_units = None
        self._revision_no = None
        self._delivery_start = None
        self._delivery_end = None
        self._best_bid_price = None
        self._best_bid_quantity = None
        self._best_ask_price = None
        self._best_ask_quantity = None
        self._last_price = None
        self._last_quantity = None
        self._total_quantity = None
        self._auction_price = None
        self._high = None
        self._low = None
        self._last_trade_time = None
        self._signals = None
        self._vwap = None
        self._avwa = None
        self._bvwa = None
        self._trading_start = None
        self._trading_end = None
        self._order_action_quota = None
        self._portfolio_information = None
        self.discriminator = None

        if product is not None:
            self.product = product
        if contract_id is not None:
            self.contract_id = contract_id
        if sequence_number is not None:
            self.sequence_number = sequence_number
        if type is not None:
            self.type = type
        if state is not None:
            self.state = state
        if active_since is not None:
            self.active_since = active_since
        if name is not None:
            self.name = name
        if del_units is not None:
            self.del_units = del_units
        if revision_no is not None:
            self.revision_no = revision_no
        if delivery_start is not None:
            self.delivery_start = delivery_start
        if delivery_end is not None:
            self.delivery_end = delivery_end
        if best_bid_price is not None:
            self.best_bid_price = best_bid_price
        if best_bid_quantity is not None:
            self.best_bid_quantity = best_bid_quantity
        if best_ask_price is not None:
            self.best_ask_price = best_ask_price
        if best_ask_quantity is not None:
            self.best_ask_quantity = best_ask_quantity
        if last_price is not None:
            self.last_price = last_price
        if last_quantity is not None:
            self.last_quantity = last_quantity
        if total_quantity is not None:
            self.total_quantity = total_quantity
        if auction_price is not None:
            self.auction_price = auction_price
        if high is not None:
            self.high = high
        if low is not None:
            self.low = low
        if last_trade_time is not None:
            self.last_trade_time = last_trade_time
        if signals is not None:
            self.signals = signals
        if vwap is not None:
            self.vwap = vwap
        if avwa is not None:
            self.avwa = avwa
        if bvwa is not None:
            self.bvwa = bvwa
        if trading_start is not None:
            self.trading_start = trading_start
        if trading_end is not None:
            self.trading_end = trading_end
        if order_action_quota is not None:
            self.order_action_quota = order_action_quota
        if portfolio_information is not None:
            self.portfolio_information = portfolio_information

    @property
    def product(self):
        """Gets the product of this Contract.  # noqa: E501

        the contract's product  # noqa: E501

        :return: The product of this Contract.  # noqa: E501
        :rtype: str
        """
        return self._product

    @product.setter
    def product(self, product):
        """Sets the product of this Contract.

        the contract's product  # noqa: E501

        :param product: The product of this Contract.  # noqa: E501
        :type product: str
        """

        self._product = product

    @property
    def contract_id(self):
        """Gets the contract_id of this Contract.  # noqa: E501

        The contract's unique id  # noqa: E501

        :return: The contract_id of this Contract.  # noqa: E501
        :rtype: str
        """
        return self._contract_id

    @contract_id.setter
    def contract_id(self, contract_id):
        """Sets the contract_id of this Contract.

        The contract's unique id  # noqa: E501

        :param contract_id: The contract_id of this Contract.  # noqa: E501
        :type contract_id: str
        """

        self._contract_id = contract_id

    @property
    def sequence_number(self):
        """Gets the sequence_number of this Contract.  # noqa: E501

        DEPRECATED: use revision_no instead  # noqa: E501

        :return: The sequence_number of this Contract.  # noqa: E501
        :rtype: int
        """
        return self._sequence_number

    @sequence_number.setter
    def sequence_number(self, sequence_number):
        """Sets the sequence_number of this Contract.

        DEPRECATED: use revision_no instead  # noqa: E501

        :param sequence_number: The sequence_number of this Contract.  # noqa: E501
        :type sequence_number: int
        """

        self._sequence_number = sequence_number

    @property
    def type(self):
        """Gets the type of this Contract.  # noqa: E501


        :return: The type of this Contract.  # noqa: E501
        :rtype: ContractType
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this Contract.


        :param type: The type of this Contract.  # noqa: E501
        :type type: ContractType
        """

        self._type = type

    @property
    def state(self):
        """Gets the state of this Contract.  # noqa: E501

        State of the contract  # noqa: E501

        :return: The state of this Contract.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this Contract.

        State of the contract  # noqa: E501

        :param state: The state of this Contract.  # noqa: E501
        :type state: str
        """
        allowed_values = ["ACTI", "IACT"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and state not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `state` ({0}), must be one of {1}"  # noqa: E501
                .format(state, allowed_values)
            )

        self._state = state

    @property
    def active_since(self):
        """Gets the active_since of this Contract.  # noqa: E501

        The timestamp (UTC) since when the contract has been observed as active for trading in the corresponding delivery area. Is reset to current time after a system or market outage or after the market was hibernated. Can be used to determine potential low liquidity situations after activation of new contracts or market outages.  # noqa: E501

        :return: The active_since of this Contract.  # noqa: E501
        :rtype: datetime
        """
        return self._active_since

    @active_since.setter
    def active_since(self, active_since):
        """Sets the active_since of this Contract.

        The timestamp (UTC) since when the contract has been observed as active for trading in the corresponding delivery area. Is reset to current time after a system or market outage or after the market was hibernated. Can be used to determine potential low liquidity situations after activation of new contracts or market outages.  # noqa: E501

        :param active_since: The active_since of this Contract.  # noqa: E501
        :type active_since: datetime
        """

        self._active_since = active_since

    @property
    def name(self):
        """Gets the name of this Contract.  # noqa: E501

        The name of the contract  # noqa: E501

        :return: The name of this Contract.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Contract.

        The name of the contract  # noqa: E501

        :param name: The name of this Contract.  # noqa: E501
        :type name: str
        """

        self._name = name

    @property
    def del_units(self):
        """Gets the del_units of this Contract.  # noqa: E501

        Delivery unit of the respective product. In case of product with type User-Defined Delivery Period this attribute is stored only with contract.  # noqa: E501

        :return: The del_units of this Contract.  # noqa: E501
        :rtype: float
        """
        return self._del_units

    @del_units.setter
    def del_units(self, del_units):
        """Sets the del_units of this Contract.

        Delivery unit of the respective product. In case of product with type User-Defined Delivery Period this attribute is stored only with contract.  # noqa: E501

        :param del_units: The del_units of this Contract.  # noqa: E501
        :type del_units: float
        """

        self._del_units = del_units

    @property
    def revision_no(self):
        """Gets the revision_no of this Contract.  # noqa: E501

        A running number starting at 0; Every time the contract changes (i.e. a trade is made), this number increments.  # noqa: E501

        :return: The revision_no of this Contract.  # noqa: E501
        :rtype: int
        """
        return self._revision_no

    @revision_no.setter
    def revision_no(self, revision_no):
        """Sets the revision_no of this Contract.

        A running number starting at 0; Every time the contract changes (i.e. a trade is made), this number increments.  # noqa: E501

        :param revision_no: The revision_no of this Contract.  # noqa: E501
        :type revision_no: int
        """

        self._revision_no = revision_no

    @property
    def delivery_start(self):
        """Gets the delivery_start of this Contract.  # noqa: E501

        The delivery start time (UTC) of the contract  # noqa: E501

        :return: The delivery_start of this Contract.  # noqa: E501
        :rtype: datetime
        """
        return self._delivery_start

    @delivery_start.setter
    def delivery_start(self, delivery_start):
        """Sets the delivery_start of this Contract.

        The delivery start time (UTC) of the contract  # noqa: E501

        :param delivery_start: The delivery_start of this Contract.  # noqa: E501
        :type delivery_start: datetime
        """

        self._delivery_start = delivery_start

    @property
    def delivery_end(self):
        """Gets the delivery_end of this Contract.  # noqa: E501

        The delivery end time (UTC) of the contract  # noqa: E501

        :return: The delivery_end of this Contract.  # noqa: E501
        :rtype: datetime
        """
        return self._delivery_end

    @delivery_end.setter
    def delivery_end(self, delivery_end):
        """Sets the delivery_end of this Contract.

        The delivery end time (UTC) of the contract  # noqa: E501

        :param delivery_end: The delivery_end of this Contract.  # noqa: E501
        :type delivery_end: datetime
        """

        self._delivery_end = delivery_end

    @property
    def best_bid_price(self):
        """Gets the best_bid_price of this Contract.  # noqa: E501

        The price of the best bid.  # noqa: E501

        :return: The best_bid_price of this Contract.  # noqa: E501
        :rtype: float
        """
        return self._best_bid_price

    @best_bid_price.setter
    def best_bid_price(self, best_bid_price):
        """Sets the best_bid_price of this Contract.

        The price of the best bid.  # noqa: E501

        :param best_bid_price: The best_bid_price of this Contract.  # noqa: E501
        :type best_bid_price: float
        """

        self._best_bid_price = best_bid_price

    @property
    def best_bid_quantity(self):
        """Gets the best_bid_quantity of this Contract.  # noqa: E501

        The quantity of the best bid.  # noqa: E501

        :return: The best_bid_quantity of this Contract.  # noqa: E501
        :rtype: float
        """
        return self._best_bid_quantity

    @best_bid_quantity.setter
    def best_bid_quantity(self, best_bid_quantity):
        """Sets the best_bid_quantity of this Contract.

        The quantity of the best bid.  # noqa: E501

        :param best_bid_quantity: The best_bid_quantity of this Contract.  # noqa: E501
        :type best_bid_quantity: float
        """

        self._best_bid_quantity = best_bid_quantity

    @property
    def best_ask_price(self):
        """Gets the best_ask_price of this Contract.  # noqa: E501

        The price of the best ask.  # noqa: E501

        :return: The best_ask_price of this Contract.  # noqa: E501
        :rtype: float
        """
        return self._best_ask_price

    @best_ask_price.setter
    def best_ask_price(self, best_ask_price):
        """Sets the best_ask_price of this Contract.

        The price of the best ask.  # noqa: E501

        :param best_ask_price: The best_ask_price of this Contract.  # noqa: E501
        :type best_ask_price: float
        """

        self._best_ask_price = best_ask_price

    @property
    def best_ask_quantity(self):
        """Gets the best_ask_quantity of this Contract.  # noqa: E501

        The quantity of the best ask.  # noqa: E501

        :return: The best_ask_quantity of this Contract.  # noqa: E501
        :rtype: float
        """
        return self._best_ask_quantity

    @best_ask_quantity.setter
    def best_ask_quantity(self, best_ask_quantity):
        """Sets the best_ask_quantity of this Contract.

        The quantity of the best ask.  # noqa: E501

        :param best_ask_quantity: The best_ask_quantity of this Contract.  # noqa: E501
        :type best_ask_quantity: float
        """

        self._best_ask_quantity = best_ask_quantity

    @property
    def last_price(self):
        """Gets the last_price of this Contract.  # noqa: E501

        The price of the last trade  All trades in the market area of the contract's delivery area, where at least one side of the trade happened on the current exchange, are included. Trades for the XBID contract of the same delivery period as a local contract and vice versa will also be included. Self trades registered at the exchange and internal trades registered by PowerBot are excluded.  # noqa: E501

        :return: The last_price of this Contract.  # noqa: E501
        :rtype: float
        """
        return self._last_price

    @last_price.setter
    def last_price(self, last_price):
        """Sets the last_price of this Contract.

        The price of the last trade  All trades in the market area of the contract's delivery area, where at least one side of the trade happened on the current exchange, are included. Trades for the XBID contract of the same delivery period as a local contract and vice versa will also be included. Self trades registered at the exchange and internal trades registered by PowerBot are excluded.  # noqa: E501

        :param last_price: The last_price of this Contract.  # noqa: E501
        :type last_price: float
        """

        self._last_price = last_price

    @property
    def last_quantity(self):
        """Gets the last_quantity of this Contract.  # noqa: E501

        The quantity of the last trade  All trades in the market area of the contract's delivery area, where at least one side of the trade happened on the current exchange, are included. Trades for the XBID contract of the same delivery period as a local contract and vice versa will also be included. Self trades registered at the exchange and internal trades registered by PowerBot are excluded.  # noqa: E501

        :return: The last_quantity of this Contract.  # noqa: E501
        :rtype: float
        """
        return self._last_quantity

    @last_quantity.setter
    def last_quantity(self, last_quantity):
        """Sets the last_quantity of this Contract.

        The quantity of the last trade  All trades in the market area of the contract's delivery area, where at least one side of the trade happened on the current exchange, are included. Trades for the XBID contract of the same delivery period as a local contract and vice versa will also be included. Self trades registered at the exchange and internal trades registered by PowerBot are excluded.  # noqa: E501

        :param last_quantity: The last_quantity of this Contract.  # noqa: E501
        :type last_quantity: float
        """

        self._last_quantity = last_quantity

    @property
    def total_quantity(self):
        """Gets the total_quantity of this Contract.  # noqa: E501

        The total volume of all trades  All trades in the market area of the contract's delivery area, where at least one side of the trade happened on the current exchange, are included. Trades for the XBID contract of the same delivery period as a local contract and vice versa will also be included. Each side of a trade is counted separately, so a trade with both sides in the same market area gets counted twice. Self trades registered at the exchange and internal trades registered by PowerBot are excluded.  # noqa: E501

        :return: The total_quantity of this Contract.  # noqa: E501
        :rtype: float
        """
        return self._total_quantity

    @total_quantity.setter
    def total_quantity(self, total_quantity):
        """Sets the total_quantity of this Contract.

        The total volume of all trades  All trades in the market area of the contract's delivery area, where at least one side of the trade happened on the current exchange, are included. Trades for the XBID contract of the same delivery period as a local contract and vice versa will also be included. Each side of a trade is counted separately, so a trade with both sides in the same market area gets counted twice. Self trades registered at the exchange and internal trades registered by PowerBot are excluded.  # noqa: E501

        :param total_quantity: The total_quantity of this Contract.  # noqa: E501
        :type total_quantity: float
        """

        self._total_quantity = total_quantity

    @property
    def auction_price(self):
        """Gets the auction_price of this Contract.  # noqa: E501

        The reference auction price of this contract (not available for all exchanges)  # noqa: E501

        :return: The auction_price of this Contract.  # noqa: E501
        :rtype: float
        """
        return self._auction_price

    @auction_price.setter
    def auction_price(self, auction_price):
        """Sets the auction_price of this Contract.

        The reference auction price of this contract (not available for all exchanges)  # noqa: E501

        :param auction_price: The auction_price of this Contract.  # noqa: E501
        :type auction_price: float
        """

        self._auction_price = auction_price

    @property
    def high(self):
        """Gets the high of this Contract.  # noqa: E501

        The highest traded price  All trades in the market area of the contract's delivery area, where at least one side of the trade happened on the current exchange, are included. Trades for the XBID contract of the same delivery period as a local contract and vice versa will also be included. Self trades registered at the exchange and internal trades registered by PowerBot are excluded.  # noqa: E501

        :return: The high of this Contract.  # noqa: E501
        :rtype: float
        """
        return self._high

    @high.setter
    def high(self, high):
        """Sets the high of this Contract.

        The highest traded price  All trades in the market area of the contract's delivery area, where at least one side of the trade happened on the current exchange, are included. Trades for the XBID contract of the same delivery period as a local contract and vice versa will also be included. Self trades registered at the exchange and internal trades registered by PowerBot are excluded.  # noqa: E501

        :param high: The high of this Contract.  # noqa: E501
        :type high: float
        """

        self._high = high

    @property
    def low(self):
        """Gets the low of this Contract.  # noqa: E501

        The lowest traded price  All trades in the market area of the contract's delivery area, where at least one side of the trade happened on the current exchange, are included. Trades for the XBID contract of the same delivery period as a local contract and vice versa will also be included. Self trades registered at the exchange and internal trades registered by PowerBot are excluded.  # noqa: E501

        :return: The low of this Contract.  # noqa: E501
        :rtype: float
        """
        return self._low

    @low.setter
    def low(self, low):
        """Sets the low of this Contract.

        The lowest traded price  All trades in the market area of the contract's delivery area, where at least one side of the trade happened on the current exchange, are included. Trades for the XBID contract of the same delivery period as a local contract and vice versa will also be included. Self trades registered at the exchange and internal trades registered by PowerBot are excluded.  # noqa: E501

        :param low: The low of this Contract.  # noqa: E501
        :type low: float
        """

        self._low = low

    @property
    def last_trade_time(self):
        """Gets the last_trade_time of this Contract.  # noqa: E501

        The time of the last trade  All trades in the market area of the contract's delivery area, where at least one side of the trade happened on the current exchange, are included. Trades for the XBID contract of the same delivery period as a local contract and vice versa will also be included. Self trades registered at the exchange and internal trades registered by PowerBot are excluded.  # noqa: E501

        :return: The last_trade_time of this Contract.  # noqa: E501
        :rtype: datetime
        """
        return self._last_trade_time

    @last_trade_time.setter
    def last_trade_time(self, last_trade_time):
        """Sets the last_trade_time of this Contract.

        The time of the last trade  All trades in the market area of the contract's delivery area, where at least one side of the trade happened on the current exchange, are included. Trades for the XBID contract of the same delivery period as a local contract and vice versa will also be included. Self trades registered at the exchange and internal trades registered by PowerBot are excluded.  # noqa: E501

        :param last_trade_time: The last_trade_time of this Contract.  # noqa: E501
        :type last_trade_time: datetime
        """

        self._last_trade_time = last_trade_time

    @property
    def signals(self):
        """Gets the signals of this Contract.  # noqa: E501

        The signals applicable for the contract  # noqa: E501

        :return: The signals of this Contract.  # noqa: E501
        :rtype: list[Signal]
        """
        return self._signals

    @signals.setter
    def signals(self, signals):
        """Sets the signals of this Contract.

        The signals applicable for the contract  # noqa: E501

        :param signals: The signals of this Contract.  # noqa: E501
        :type signals: list[Signal]
        """

        self._signals = signals

    @property
    def vwap(self):
        """Gets the vwap of this Contract.  # noqa: E501

        The volume weighted average price  All trades in the market area of the contract's delivery area, where at least one side of the trade happened on the current exchange, are included. Trades for the XBID contract of the same delivery period as a local contract and vice versa will also be included. Each side of a trade is counted separately, so a trade with both sides in the same market area gets counted twice. Self trades registered at the exchange and internal trades registered by PowerBot are excluded.  # noqa: E501

        :return: The vwap of this Contract.  # noqa: E501
        :rtype: float
        """
        return self._vwap

    @vwap.setter
    def vwap(self, vwap):
        """Sets the vwap of this Contract.

        The volume weighted average price  All trades in the market area of the contract's delivery area, where at least one side of the trade happened on the current exchange, are included. Trades for the XBID contract of the same delivery period as a local contract and vice versa will also be included. Each side of a trade is counted separately, so a trade with both sides in the same market area gets counted twice. Self trades registered at the exchange and internal trades registered by PowerBot are excluded.  # noqa: E501

        :param vwap: The vwap of this Contract.  # noqa: E501
        :type vwap: float
        """

        self._vwap = vwap

    @property
    def avwa(self):
        """Gets the avwa of this Contract.  # noqa: E501

        Volume weighted average price of all asks in the order book  # noqa: E501

        :return: The avwa of this Contract.  # noqa: E501
        :rtype: float
        """
        return self._avwa

    @avwa.setter
    def avwa(self, avwa):
        """Sets the avwa of this Contract.

        Volume weighted average price of all asks in the order book  # noqa: E501

        :param avwa: The avwa of this Contract.  # noqa: E501
        :type avwa: float
        """

        self._avwa = avwa

    @property
    def bvwa(self):
        """Gets the bvwa of this Contract.  # noqa: E501

        Volume weighted average price of all bids in the order book  # noqa: E501

        :return: The bvwa of this Contract.  # noqa: E501
        :rtype: float
        """
        return self._bvwa

    @bvwa.setter
    def bvwa(self, bvwa):
        """Sets the bvwa of this Contract.

        Volume weighted average price of all bids in the order book  # noqa: E501

        :param bvwa: The bvwa of this Contract.  # noqa: E501
        :type bvwa: float
        """

        self._bvwa = bvwa

    @property
    def trading_start(self):
        """Gets the trading_start of this Contract.  # noqa: E501

        The trading start time of the contract (only available when the contract is active)  # noqa: E501

        :return: The trading_start of this Contract.  # noqa: E501
        :rtype: datetime
        """
        return self._trading_start

    @trading_start.setter
    def trading_start(self, trading_start):
        """Sets the trading_start of this Contract.

        The trading start time of the contract (only available when the contract is active)  # noqa: E501

        :param trading_start: The trading_start of this Contract.  # noqa: E501
        :type trading_start: datetime
        """

        self._trading_start = trading_start

    @property
    def trading_end(self):
        """Gets the trading_end of this Contract.  # noqa: E501

        The trading end time of the contract (only available when the contract is active)  # noqa: E501

        :return: The trading_end of this Contract.  # noqa: E501
        :rtype: datetime
        """
        return self._trading_end

    @trading_end.setter
    def trading_end(self, trading_end):
        """Sets the trading_end of this Contract.

        The trading end time of the contract (only available when the contract is active)  # noqa: E501

        :param trading_end: The trading_end of this Contract.  # noqa: E501
        :type trading_end: datetime
        """

        self._trading_end = trading_end

    @property
    def order_action_quota(self):
        """Gets the order_action_quota of this Contract.  # noqa: E501

        **Only supported for EPEX, Nord Pool, IBEX and CROPEX**  The percentage (0.0 - 1.0) of consumed order entry/modification quota calculated depending on the underlying exchange.  This value is calculated based on the following formula:  `max{short_usage/short_limit, long_usage/long_limit}`  # noqa: E501

        :return: The order_action_quota of this Contract.  # noqa: E501
        :rtype: float
        """
        return self._order_action_quota

    @order_action_quota.setter
    def order_action_quota(self, order_action_quota):
        """Sets the order_action_quota of this Contract.

        **Only supported for EPEX, Nord Pool, IBEX and CROPEX**  The percentage (0.0 - 1.0) of consumed order entry/modification quota calculated depending on the underlying exchange.  This value is calculated based on the following formula:  `max{short_usage/short_limit, long_usage/long_limit}`  # noqa: E501

        :param order_action_quota: The order_action_quota of this Contract.  # noqa: E501
        :type order_action_quota: float
        """

        self._order_action_quota = order_action_quota

    @property
    def portfolio_information(self):
        """Gets the portfolio_information of this Contract.  # noqa: E501


        :return: The portfolio_information of this Contract.  # noqa: E501
        :rtype: list[PortfolioInformation]
        """
        return self._portfolio_information

    @portfolio_information.setter
    def portfolio_information(self, portfolio_information):
        """Sets the portfolio_information of this Contract.


        :param portfolio_information: The portfolio_information of this Contract.  # noqa: E501
        :type portfolio_information: list[PortfolioInformation]
        """

        self._portfolio_information = portfolio_information

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Contract):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Contract):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    PowerBot - Webservice for algotrading

    # TERMS AND CONDITIONS The PowerBot system provides B2B services for trading at intraday power markets. By using the PowerBot service, each user agrees to the terms and conditions of this licence: 1. The user confirms that they are familiar with the exchanges trading system and all relevant rules, is professionally qualified and in possession of a trading license for the relevant exchange. 2. The user will comply with the exchanges market rules (e.g. [EPEX Spot Market Rules](https://www.epexspot.com/en/downloads#rules-fees-processes) or [Nord Pool Market Rules](https://www.nordpoolgroup.com/trading/Rules-and-regulations/)) and will not endanger the exchange system at any time with heavy load from trading algorithms or by other use. 3. The user is aware of limits imposed by the exchange. 4. The user is solely liable for actions resulting from the use of PowerBot.   # INTRODUCTION PowerBot is a web-based software service enabling algorithmic trading on intraday power exchanges such as EPEX, Nord Pool, HUPX, BSP Southpool, TGE, OPCOM or ETPA. The service is straightforward to integrate in an existing software environment and provides a variety of programming interfaces for development of individual trading algorithms and software tools. Besides enabling fully automated intraday trading, it can be used to create tools for human traders providing relevant information and trading opportunities or can be integrated in existing software tools. For further details see https://www.powerbot-trading.com  ## Knowledge Base In addition to this API guide, please find the documentation at https://docs.powerbot-trading.com - the password will be provided by the PowerBot team. If not, please reach out to us at support@powerbot-trading.com  ## Endpoints The PowerBot service is available at the following REST endpoints:  | Instance      | Base URL for REST Endpoints                                      | |---------------|------------------------------------------------------------------| | EPEX          | https://staging.powerbot-trading.com/playground/epex/v2/api      | | Nord Pool     | https://staging.powerbot-trading.com/playground/nordpool/v2/api  | | HUPX          | https://staging.powerbot-trading.com/playground/hupx/v2/api      | | BSP Southpool | https://staging.powerbot-trading.com/playground/southpool/v2/api | | TGE           | https://staging.powerbot-trading.com/playground/tge/v2/api       | | IBEX          | https://staging.powerbot-trading.com/playground/ibex/v2/api      | | CROPEX        | https://staging.powerbot-trading.com/playground/cropex/v2/api    | | OPCOM         | https://staging.powerbot-trading.com/playground/opcom/v2/api     | | ETPA          | https://staging.powerbot-trading.com/playground/etpa/v2/api      | | BRM           | https://staging.powerbot-trading.com/playground/brm/v2/api       |  Access to endpoints is secured via an API Key, which needs to be passed as an \"api_key\" header in each request.   Notes on API Keys:  * API keys are specific to Test, Staging or Production.  * API keys are generated by the system administrator and need to be requested.  ## How to generate API clients (libraries) This OpenAPI specification can be used to generate API clients (programming libraries) for a wide range of programming languages using tools like [OpenAPI Generator](https://openapi-generator.tech/). A detailed guide can be found in the [knowledge base](https://docs.powerbot-trading.com/articles/getting-started/generating-clients/).  ## PowerBot Python client For Python, a ready-made client is also available on PyPI and can be downloaded locally via:  ```shell   pip install powerbot-client ```  ## Errors The API uses standard HTTP status codes to indicate the success or failure of the API call. The body of the response will be in JSON format as follows:  ``` {   \"message\": \"... an error message ...\" } ```  ## Paging The API uses offset and limit parameters for paged operations. An X-Total-Count header is added to responses to indicate the total number of items in a paged response.  ## API Rate Limiting The API limits the number of concurrent calls to 50 - when that limit is reached, the client will receive 503 http status codes (service unavailable) with the following text:  ``` {   \"message\": \"API rate limit exceeded\" } ``` Clients should ensure that they stay within the limit for concurrent API calls.    ## Additional code samples Additional information and code samples demonstrating the use of the API can be found at in our [knowledge base](https://docs.powerbot-trading.com/docs/programmatic-access/)  # noqa: E501

    The version of the OpenAPI document: 2.21.0-rc1
    Contact: office@powerbot-trading.com
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from powerbot_asyncio_client.configuration import Configuration


class AuditLogEntry(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'received': 'datetime',
        'api_key_name': 'str',
        'ip_address': 'str',
        'tenant_id': 'str',
        'portfolio_id': 'str',
        'portfolio_ids': 'list[str]',
        'comment': 'str',
        'object_name': 'str',
        'old_value': 'list[object]',
        'new_value': 'list[object]'
    }

    attribute_map = {
        'id': 'id',
        'received': 'received',
        'api_key_name': 'api_key_name',
        'ip_address': 'ip_address',
        'tenant_id': 'tenant_id',
        'portfolio_id': 'portfolio_id',
        'portfolio_ids': 'portfolio_ids',
        'comment': 'comment',
        'object_name': 'object_name',
        'old_value': 'old_value',
        'new_value': 'new_value'
    }

    def __init__(self, id=None, received=None, api_key_name=None, ip_address=None, tenant_id=None, portfolio_id=None, portfolio_ids=None, comment=None, object_name=None, old_value=None, new_value=None, local_vars_configuration=None):  # noqa: E501
        """AuditLogEntry - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._received = None
        self._api_key_name = None
        self._ip_address = None
        self._tenant_id = None
        self._portfolio_id = None
        self._portfolio_ids = None
        self._comment = None
        self._object_name = None
        self._old_value = None
        self._new_value = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if received is not None:
            self.received = received
        if api_key_name is not None:
            self.api_key_name = api_key_name
        if ip_address is not None:
            self.ip_address = ip_address
        if tenant_id is not None:
            self.tenant_id = tenant_id
        if portfolio_id is not None:
            self.portfolio_id = portfolio_id
        if portfolio_ids is not None:
            self.portfolio_ids = portfolio_ids
        if comment is not None:
            self.comment = comment
        if object_name is not None:
            self.object_name = object_name
        if old_value is not None:
            self.old_value = old_value
        if new_value is not None:
            self.new_value = new_value

    @property
    def id(self):
        """Gets the id of this AuditLogEntry.  # noqa: E501

        The unique id of the log entry  # noqa: E501

        :return: The id of this AuditLogEntry.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this AuditLogEntry.

        The unique id of the log entry  # noqa: E501

        :param id: The id of this AuditLogEntry.  # noqa: E501
        :type id: str
        """

        self._id = id

    @property
    def received(self):
        """Gets the received of this AuditLogEntry.  # noqa: E501

        The timestamp when the trading API has received the log entry. UTC timezone is used.  # noqa: E501

        :return: The received of this AuditLogEntry.  # noqa: E501
        :rtype: datetime
        """
        return self._received

    @received.setter
    def received(self, received):
        """Sets the received of this AuditLogEntry.

        The timestamp when the trading API has received the log entry. UTC timezone is used.  # noqa: E501

        :param received: The received of this AuditLogEntry.  # noqa: E501
        :type received: datetime
        """

        self._received = received

    @property
    def api_key_name(self):
        """Gets the api_key_name of this AuditLogEntry.  # noqa: E501

        The api_key from which the audit log was generated  # noqa: E501

        :return: The api_key_name of this AuditLogEntry.  # noqa: E501
        :rtype: str
        """
        return self._api_key_name

    @api_key_name.setter
    def api_key_name(self, api_key_name):
        """Sets the api_key_name of this AuditLogEntry.

        The api_key from which the audit log was generated  # noqa: E501

        :param api_key_name: The api_key_name of this AuditLogEntry.  # noqa: E501
        :type api_key_name: str
        """

        self._api_key_name = api_key_name

    @property
    def ip_address(self):
        """Gets the ip_address of this AuditLogEntry.  # noqa: E501

        The IP-address from which the audit log was generated  # noqa: E501

        :return: The ip_address of this AuditLogEntry.  # noqa: E501
        :rtype: str
        """
        return self._ip_address

    @ip_address.setter
    def ip_address(self, ip_address):
        """Sets the ip_address of this AuditLogEntry.

        The IP-address from which the audit log was generated  # noqa: E501

        :param ip_address: The ip_address of this AuditLogEntry.  # noqa: E501
        :type ip_address: str
        """

        self._ip_address = ip_address

    @property
    def tenant_id(self):
        """Gets the tenant_id of this AuditLogEntry.  # noqa: E501

        The tenant for which the log entry is applicable  # noqa: E501

        :return: The tenant_id of this AuditLogEntry.  # noqa: E501
        :rtype: str
        """
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        """Sets the tenant_id of this AuditLogEntry.

        The tenant for which the log entry is applicable  # noqa: E501

        :param tenant_id: The tenant_id of this AuditLogEntry.  # noqa: E501
        :type tenant_id: str
        """

        self._tenant_id = tenant_id

    @property
    def portfolio_id(self):
        """Gets the portfolio_id of this AuditLogEntry.  # noqa: E501

        DEPRECATED: replaced by portfolio ids. The portfolio for which the log entry is applicable   # noqa: E501

        :return: The portfolio_id of this AuditLogEntry.  # noqa: E501
        :rtype: str
        """
        return self._portfolio_id

    @portfolio_id.setter
    def portfolio_id(self, portfolio_id):
        """Sets the portfolio_id of this AuditLogEntry.

        DEPRECATED: replaced by portfolio ids. The portfolio for which the log entry is applicable   # noqa: E501

        :param portfolio_id: The portfolio_id of this AuditLogEntry.  # noqa: E501
        :type portfolio_id: str
        """

        self._portfolio_id = portfolio_id

    @property
    def portfolio_ids(self):
        """Gets the portfolio_ids of this AuditLogEntry.  # noqa: E501

        The portfolios for which the log entry is applicable  # noqa: E501

        :return: The portfolio_ids of this AuditLogEntry.  # noqa: E501
        :rtype: list[str]
        """
        return self._portfolio_ids

    @portfolio_ids.setter
    def portfolio_ids(self, portfolio_ids):
        """Sets the portfolio_ids of this AuditLogEntry.

        The portfolios for which the log entry is applicable  # noqa: E501

        :param portfolio_ids: The portfolio_ids of this AuditLogEntry.  # noqa: E501
        :type portfolio_ids: list[str]
        """

        self._portfolio_ids = portfolio_ids

    @property
    def comment(self):
        """Gets the comment of this AuditLogEntry.  # noqa: E501

        information about the cause of the change  # noqa: E501

        :return: The comment of this AuditLogEntry.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this AuditLogEntry.

        information about the cause of the change  # noqa: E501

        :param comment: The comment of this AuditLogEntry.  # noqa: E501
        :type comment: str
        """

        self._comment = comment

    @property
    def object_name(self):
        """Gets the object_name of this AuditLogEntry.  # noqa: E501

        the changed object  # noqa: E501

        :return: The object_name of this AuditLogEntry.  # noqa: E501
        :rtype: str
        """
        return self._object_name

    @object_name.setter
    def object_name(self, object_name):
        """Sets the object_name of this AuditLogEntry.

        the changed object  # noqa: E501

        :param object_name: The object_name of this AuditLogEntry.  # noqa: E501
        :type object_name: str
        """

        self._object_name = object_name

    @property
    def old_value(self):
        """Gets the old_value of this AuditLogEntry.  # noqa: E501

        The old value of the changed entry  # noqa: E501

        :return: The old_value of this AuditLogEntry.  # noqa: E501
        :rtype: list[object]
        """
        return self._old_value

    @old_value.setter
    def old_value(self, old_value):
        """Sets the old_value of this AuditLogEntry.

        The old value of the changed entry  # noqa: E501

        :param old_value: The old_value of this AuditLogEntry.  # noqa: E501
        :type old_value: list[object]
        """

        self._old_value = old_value

    @property
    def new_value(self):
        """Gets the new_value of this AuditLogEntry.  # noqa: E501

        The new value of the changed entry  # noqa: E501

        :return: The new_value of this AuditLogEntry.  # noqa: E501
        :rtype: list[object]
        """
        return self._new_value

    @new_value.setter
    def new_value(self, new_value):
        """Sets the new_value of this AuditLogEntry.

        The new value of the changed entry  # noqa: E501

        :param new_value: The new_value of this AuditLogEntry.  # noqa: E501
        :type new_value: list[object]
        """

        self._new_value = new_value

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AuditLogEntry):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AuditLogEntry):
            return True

        return self.to_dict() != other.to_dict()
